----------------------------------------------------------------------
--
-- custom.example.lua - Optional; create custom tabard categories for
--	TabardMaster and reassign map zones.
--
-- Copy this file to 'custom.lua' and edit the copy as desired.
--
-- Get itemIDs for tabards from AllTabards.txt or WoWHead.com, etc.
-- Generate mapIDs with '/tm dumpall' - dumps all valid mapIDs into 
--	(account)/SavedVariables/TabardMaster.lua under 'develMaps'.
--
----------------------------------------------------------------------

----------------------------------------------------------------------
-- Change the tabard categories
----------------------------------------------------------------------
-- Usage example: create a custom tabard category using the following 
-- 	6 tabards:
-- 		Tabard of the Lightbringer 	(itemID 52252), 
--		Loremaster's Colors 		(itemID 43300),
-- 		Tabard of the Achiever 		(itemID 40643), 
--		Tabard of the Void 			(itemID 38311),
-- 		Tabard of Nature 			(itemID 38309), and 
--		Tabard of Brilliance 		(itemID 38312).
-- 	The description of this new category will be 'My epic collection'.
--  
-- Using just the itemIDs, the new tabard category entry would be
-- tm_tabardGroup["user0"] = "52252 43300 40643 38311 38309 38312"
-- And, to give it a description that appears in the category menu & tabard info line,
-- tm_lang["user0"] = "My |cffa335eeepic|r collection"
--
-- Simply replace one of the entries below with your custom tabard category.
--
-- To use this new category, open TabardMaster's main options panel and select the custom
-- category from the dropdown menus.  Then press 'Save'.  Now every time you are in that 
-- group type, one of the tabards from 'My epic collection' will be equipped. 
-- Of course, you have to have the tabard in your inventory, and tabard swaps must be enabled.

tm_tabardGroup["user0"] = ""
tm_lang["user0"] = ""
tm_tabardGroup["user1"] = ""
tm_lang["user1"] = ""
tm_tabardGroup["user2"] = ""
tm_lang["user2"] = ""
tm_tabardGroup["user2"] = ""
tm_lang["user2"] = ""
tm_tabardGroup["user3"] = ""
tm_lang["user3"] = ""
tm_tabardGroup["user4"] = ""
tm_lang["user4"] = ""
tm_tabardGroup["user5"] = ""
tm_lang["user5"] = ""
tm_tabardGroup["user6"] = ""
tm_lang["user6"] = ""
tm_tabardGroup["user7"] = ""
tm_lang["user7"] = ""
tm_tabardGroup["user8"] = ""
tm_lang["user8"] = ""
tm_tabardGroup["user9"] = ""
tm_lang["user9"] = ""

--	The default tabard categories are: 'guild', 'cities', 'arena', 'misc', 'D70tabards', 'D80tabards', 
--		'D85tabards', 'D90tabards', 'D100tabards'
-- The default tabard category assignments are:
-- 		category	entry
-----------------------------------
--		guild 		"guild"			- contains the 3 guild tabards
--		pvp 		"arena"			- contains tabards earned from PvP factions
--		solo 		"guild"			
--		misc 		"misc"			- contains tabards not otherwise categorized
--		city 		"cities"		- contains all city tabards
--		raid 		"cities"
--		D60 		"cities"
--		D70 		"D70tabards"	- contains tabards issued by factions in the Burning Crusades expansion
--		D80 		"D80tabards"	- contains tabards issued by factions in the Lich King expansion
--		D85 		"D85tabards"	- contains tabards issued by factions in the Cataclysm expansion
--		D90 		"D90tabards"	- contains tabards issued by factions in the Mists of Pandaria expansion
--		D100 		"D100tabards"	- contains tabards issued by factions in the Warlords of Draenor expansion

--	There is no need to redefine the default entries, simply reassign them using this array.
tm_tabardGroup['override'] = {
	['guild'] 		= '',
	-- ['guild'] 	= '69210 62909 5976 45574',						-- Example adds Stormwind Tabard (itemID 45574) as a guild tabard 
	-- ['cities'] 	= tm_tabardGroup['user0'],						-- Example - see below
	-- ['cities']	= '52252 43300 40643 38311 38309 38312',		-- Example - see below
	['cities'] 		= '',
	['arena'] 		= '',
	['misc'] 		= '',
	['D70tabards'] 	= '',
	['D80tabards'] 	= '',
	['D85tabards'] 	= '',
	['D90tabards'] 	= '',
	['D100tabards']	= '',
}

-- Default itemIDs for the 'city' tabard category are: "45574 45577 45578 45579 45580 45581 45582 45583 45584 45585 64882 64884"
-- To change the city tabard category to always use one of the tabards from 'My epic collection', 
-- change the 'cities' entry above to be
--		['cities'] = tm_tabardGroup['user0'],
-- or
--		['cities'] = "52252 43300 40643 38311 38309 38312",

----------------------------------------------------------------------
-- Change the map definitions
----------------------------------------------------------------------

-- Tabardmaster checks for new zone mapIDs anytime the client changes 
--	versions, and any new zones discovered are added to the dungeon 
--	category for the current expansion.  (Currently D100.)
--
-- IMPORTANT: redefining map zones affects both tabard and equipment 
--	set changes; mistakes could result in a vanity gearset being 
--	equipped in a dungeon or raid.  Be careful.
--
----------------------------------------------------------------------

-- Notes:
-- the 2 Pandarian Shrines use mapID 811
-- Lunarfall (Alliance garrison) uses mapID 971 and (unresolved) 973, 974, 975
-- Frostwall (Horde garrison) uses mapID 976 and (unresolved) 980, 981, 982
-- 	(The 4 mapIDs represent each garrison level.)

--[[ 
	Default map categories and descriptions
	
	['allianceCities']			- Alliance friendly cities, Horde PvP zone
	['hordeCities']				- Horde friendly cities, Alliance PvP zone
	['city']					- Sanctuary cities (Shattrath, Dalaran)
	['pvp']						- world PvP zones (Wintergrasp, Tol Barad)
	['Battlegrounds']			- battlegrounds (and arenas)

	['Kalimdor']				- Kalimdor PvE zones
	['Eastern Kingdoms'] 		- Eastern Kingdon PvE zones 
	['Classic Raids']  			- Classic raids
	['D60']  					- Classic dungeons
	
	['Outland'] 		 		- Outland PvE zones
	['Outland Raids'] 	 		- Outland raids
	['D70'] 			 		- Outland dungeons

	['Northrend'] 	 			- Northrend PvE zones
	['Northrend Raids']  		- Northrend
	['D80'] 			 		- Northrend dungeons
	['H80'] 			 		- Northrend dungeons that need heroic mode to champion
	
	['Cataclysm'] 		 		- Cataclysm PvE zones
	['Cataclysm Raids']	 		- Cataclysm raids
	['D85'] 			 		- Cataclysm dungeons
	['H85'] 			 		- Cataclysm dungeons that need heroic mode to champion
	['X85'] 			 		- Classic dungeons with Cataclysm mode

	['Pandaria']		 		- Pandaria PvE zones
	['Pandaria Raids']	 		- Pandaria raids
	['Pandaria Scenarios'] 		- Pandaria scenarios
	['D90'] 			 		- Pandaria dungeons
	['H90'] 			 		- Pandaria dungeons that need heroic mode to champion
	['X90'] 			 		- Classic dungeons with Pandaria mode
	
	['Draenor']			 		- Draenor PvE zones
	['Draenor Raids']			- Draenor raids
	['Draenor Scenarios'] 		- Draenor scenarios
	['D100']		 			- Draenor dungeons
	['H100']			 		- Draenor dungeons that need heroic mode to champion
	['X100']			 		- Classic dungeons with Draenor mode
]]

-- Example to change mapIDs for garrisons from their default 'Dreanor' definition
--	into faction city zones.  
tm_maps['override'] = {
	['allianceCities'] = '971 973 974 975',		-- Lunarfall (and it's alternate mapIDs) is an alliance city 
	['hordeCities'] = '976 980 981 982',		-- Frostwall (and it's alternate mapIDs) is a horde city
}

