----------------------------------------------------------------------
--
-- language.lua - localized language translations for TabardMaster
--
-- Define the replaceable text fields and localized versions that
-- constitute TabardMaster's displays and messages.  Individually
-- commented as needed.
--
-- To create custom messages or entire language sets, place all
-- tm_lang[] entries inside the individual language code sections
-- below the default definitions.
--
-- Faction names, instance names, and reputations are localized via
-- the game client.
--
-- Text can be colored by enclosing it in a |c ... |r sequence.  The
-- full sequence is '|cAARRGGBBtext to show|r' where: '|c' is the
-- code that starts the sequence, 'AA' is the alpha channel blend
-- of the text to display (which is currently ignored and should be
-- left as 'FF'), and 'RR', 'GG', and 'BB' are the red, green, and
-- blue color components.  'AA', 'RR', 'GG', and 'BB' are expressed
-- as 2 digit hexadecimal codes (0 - 255 decimal) and can be either
-- upper or lower case.  Next comes the actual text to display,
-- followed by the terminating code of '|r'.  Any text that follows
-- the terminating code reverts to the color that was previously
-- active.  Some RRGGBB examples; FF0000 = Red text, 00FF00 = Green 
-- text, 0000FF = Blue text, FFFF00 = Yellow text.
----------------------------------------------------------------------


----------------------------------------------------------------------
-- Override internal values for use in localizing TabardMaster.
-- All buttons and checkboxes share a common size and group spacing,
-- but these can be overridden for individual translations with the 
-- following array; defaults are shown.
----------------------------------------------------------------------
tm_overrides = {
	--	All buttons and checkboxes share a common size.
	--['buttonHeight']  			= 24,									-- Button height and
	--['buttonWidth']  			 	= 100,									-- width for most buttons
	--['checkboxSize']  			= 24,									-- Size of all (square) checkboxes

	-- vertical spacing between option panel widgets
	--['verticalSpace']	 			= 40,

	-- default font sizes used
	--['titleFont']					= 'GameFontNormalLarge',
	--['subtitleFont']				= 'GameFontHighlightSmall',
	--['checkbutonFont']			= 'GameFontHighlightSmall',
	--['maingroupFont']				= 'GameFontHighlightSmall',
	--['menuFont'] 					= 'GameFontHighlightSmall',
	--['paneltitleFont']			= 'GameFontNormal',

	-- popup menu colors
	--['menuColorTitle']			=	'|cffffa03c',						-- color to use for menu titles (orange)
	--['menuColorGroup']			=	'|cffffff00',						-- color to use for menu headers & seperators
	--['menuColorFixed']			=	'|cffffa03c',						-- color to use for selectable menu entries
	--['menuColorEntry']			=	'|cffffa03c',						-- color to use for selectable menu entries
}


----------------------------------------------------------------------
-- Get an icon for lfgNONE role, from FrameXML / MapBar.lua 
-- This should really be in baseline code, but is needed here due to
-- the LFG entries.
----------------------------------------------------------------------
local factionGroup = UnitFactionGroup('player')
if (factionGroup == 'Alliance') then
	factionIcon = '|TInterface\\TargetingFrame\\UI-PVP-ALLIANCE:19:16:0:0:64:64:0:32:0:38|t '
elseif (factionGroup == 'Horde') then
	factionIcon = '|TInterface\\TargetingFrame\\UI-PVP-HORDE:18:19:0:0:64:64:0:38:0:36|t '	
else --Say what?
	factionIcon = ''
end


----------------------------------------------------------------------
-- This is the default(US English) version of changeable text.  
-- Entries here should be duplicated in the individual localized 
-- language sections that follow.
----------------------------------------------------------------------
tm_lang = {}
-- 	what to call this addon (non English only)
	tm_lang['tabardmaster'] 			= 	'TabardMaster'

-- tell other addons about us
	tm_lang['notes'] 					= 	'Change tabard and / or gear set based on zone or group type.'
	
	
-- Used in slash decoder & info panel PVP flag (lower cased)
	tm_lang['on'] = 'on'
	tm_lang['off'] = 'off'
	tm_lang['reset'] = 'reset'
	

-- For decoding slash command requests - in lowercase
	tm_lang['slash1']					=	'/tm'								-- slash commands to look for; combine with any one of the following ...
	tm_lang['slash2']					=	'/tabardmaster'
	tm_lang['quiet1'] 					= 	'quiet' 							-- quiet mode; turns off popups & chat window messages 
	tm_lang['quiet2'] 					= 	'q'
	tm_lang['info1'] 					= 	'info'								-- show / hide info panel
	tm_lang['info2'] 					= 	'i'
	tm_lang['lock1'] 					= 	'lock'								-- lock / enable tabard & gear swaps
	tm_lang['lock2'] 					= 	'l'
	tm_lang['ts1'] 						= 	'swaptabards'						-- enable / disable tabard changes
	tm_lang['ts2'] 						= 	'st'
	tm_lang['gs1'] 						= 	'swapgear'							-- enable / disable gearset changes
	tm_lang['gs2'] 						= 	'sg'
	tm_lang['gear1'] 					= 	'gear'								-- open gearmaster panel
	tm_lang['gear2'] 					= 	'gm'
	tm_lang['dungeon1'] 				= 	'dungeon'							-- open dungeons panel
	tm_lang['dungeon2'] 				= 	'dm'
	tm_lang['help'] 					= 	'help'								-- 'help' term to check for

	-- (name of a gearset)			will wear that gearset; all pieces may not be equipped if combat flag is active
	-- (number)						will wear the tabard with an itemID of number if combat flag isn't active
	-- (name of tabard category)	will wear a random tabard from the named category
	-- debug						turns debug mode on & off, saved per character (debug mode doesn't need to be active to use!)

-- Message boxes (popups)
	-- tm_lang['mbox_109'] 				=	"TabardMaster's LFG role gearset usage\nhas changed; role gearsets now\ntake priority over instance gearsets.\n"
	tm_lang['mbox_125'] 				= 	"Tabardmaster: This is an interim release.  The\nInfoPanel is now resizable and saved per\ncharacter.  The 'Advanced' panel\n is still a work in progress."
	
	tm_lang['mbox_exalted']	 			= 	"\nCongratulations!\nYou are now exalted with %f.\nWould you like to review TabardMaster's settings?\n" -- %f replaced with faction or guild name

	
-- Chat window messages
	-- Intro line to announce readiness
	tm_lang['intro'] 					= 	"%t v%v - I'm ready to play" 		--< %t is replaced with add-on name, %v is replaced by version #
	-- help was requested
	tm_lang['helptext'] 				= 	"TabardMaster recognises the following commands:\n\"/tm q\" or \"/tm quiet\" will change between verbose modes (status messages in chat window),\n\"/tm\" will open the main options panel,\n\"/tm gm\" will open the GearMaster options panel,\n\"/tm dm\" will open the instance (dungeon) options panel.\n\"/tm st\" and \"/tm sg\" toggles swapping tabards and gear sets (respectively) on or off, and\n\"tm l\" enables or disables all swaps for this session."
	-- for reporting a tabard change
	tm_lang['tabardchange'] 			= 	'|cffffff78TabardMaster: Changing tabard to|r %t' -- %t will be replaced with tabard name
	-- when tabard can't be equipped because it's not in bags
	tm_lang['tabardmissing'] 			= 	'|cffffd200TabardMaster: |cff9f006fTabard|r %t |cff9f006fis missing from inventory|r' -- %t will be replaced with tabard name
	-- when tabard can't be removed due to a full inventory
	tm_lang['fullbags'] 				= 	'|cffffff78TabardMaster: |cff9f006fCannot remove tabard, bags are full|r'
	-- and for tabard removal
	tm_lang['tabardremoved']	 		= 	'|cffffff78TabardMaster: Removing tabard %t|r' -- %t will be replaced with tabard name
	-- "Combat flag has tabard swaps locked out" warning
	tm_lang['lockout']					=	'Tabard swaps are not allowed while in combat, delaying.'
	-- for reporting an equipment set change
	tm_lang['gearchange'] 				= 	'|cffffff78TabardMaster: Changing equipment set to|r %e' -- %e will be replaced with gearset name

	tm_lang['feedback state'] 			=	{'TabardMaster reporting is off',
											 'TabardMaster reporting via messages only',
											 'TabardMaster reporting via messages and popups',
											 'TabardMaster is in debug mode'}
	
	tm_lang['noinfoframe'] 				=	"TabardMaster's info frame is not yet available, try again later."

	
-- Info frame 
	tm_lang['chkinfoEnabletip']				=	'Shows current zone type, tabard, gearset, and flags'
	tm_lang['chkinfoEnabletext']			= 	'Show an information panel for current character'

	tm_lang['infoframeWaiting'] 			=	'    Waiting for zone or region change'

	tm_lang['infoframeLine1'] 				=	'Zone %s, Difficulty: %s'
	tm_lang['infoframeLine2'] 				=	'Map %d (%d) %s %s'

	tm_lang['infoframeLine3Working'] 		=	'Gear: Working'
	tm_lang['infoframeLine3Changed1']		=	'Gear: LFG %s = %s'
	tm_lang['infoframeLine3Changed2']		=	'Gear: (%s) %s'
	tm_lang['infoframeLine3Disabled']		=	'Gear: Swaps disabled'

	tm_lang['infoframeLine4Working'] 		=	'Tabard: Working'
	tm_lang['infoframeLine4Changed'] 		=	'Tabard: %s, %s (%s)'
	tm_lang['infoframeLine4Disabled']		=	'Tabard: Swaps disabled'
	
	tm_lang['infoframeCombat'] 				=	'Combat'
	tm_lang['infoframePvP'] 				=	'PvP ' -- trailing space
	tm_lang['infoframeZone'] 				=	'Zone'
	tm_lang['infoframeReputation'] 			=	'Reputation'

	tm_lang['infoframeForcePvP'] 			=	'On'
--	tm_lang['infoframeForcePvP'] 			=	'5 min'
	tm_lang['infoframeLongPvP'] 			=	'%m:%s'			-- %m = minutes, %s = seconds, %t = timer value
	tm_lang['infoframeShortPvP'] 			=	'%s'			-- %m = minutes, %s = seconds, %t = timer value
--	tm_lang['infoframeLongPvP'] 			=	'%t sec'
--	tm_lang['infoframeShortPvP'] 			=	'%t sec'
	

-- Main options panel
	-- the title and subtitle of the main options panel
	tm_lang['mainpaneltitle']			= 	'TabardMaster'
	tm_lang['mainpanelsubtitle']		= 	"Pressing each group type's '|cffdeaf25Pick Tabard|r' button shows a menu of tabards and tabard categories that can be selected and worn when in that group type.  Pick from the menu to automatically wear a specific tabard, a tabard from a category of tabards, or no tabard at all."

	-- addon control 
	tm_lang['controlpanetitle']			=	'Control'
	tm_lang['chktabardenabletip']		=	'Enable tabard swaps\nTurns tabard swapping on and off'
	tm_lang['chktabardenabletext']		=	'Enable tabard swapping'
	tm_lang['chkgearenabletip']			=	'Enable gearset swaps\nTurns gearset swapping on and off'
	tm_lang['chkgearenabletext']		=	'Enable gearset swapping'
	tm_lang['chksessionLocktip']		=	'Disable auto tabard and gear swaps for this session'
	tm_lang['chksessionLocktext']		=	'Disable auto swaps\nthis session only'

	-- texts for the main options panel buttons
	tm_lang['picktabardbutton']			= 	'|cffdeaf25Pick Tabard|r'			-- the 'pick tabard' buttons
	tm_lang['reputationbutton']			= 	'|cffdeaf25Reputations|r'			-- both reputation buttons (second one is in Instances panel)

	-- descriptors for the (upper line) tabard group types on main panel - %t gets replaced with tabard name
	tm_lang['soloTabard'] 				= 	'|cffffd200Solo tabard:|r %t'
	tm_lang['cityTabard'] 				= 	'|cffffd200City tabard:|r %t'
	tm_lang['homeTabard'] 				= 	'|cffffd200Garrison / Class Hall tabard:|r %t'
	tm_lang['raidTabard'] 				= 	'|cffffd200Raid tabard:|r %t'
	tm_lang['pvpTabard'] 				= 	'|cffffd200PvP tabard:|r %t'

	-- display reputation with a faction on second line; %f will be replaced with faction (or guild) name, and %n is a gender specific rank - see below.
	tm_lang['reputation'] 				= 	'Reputation with %f is %n'
	--	The displayed reputation entries are a combination of tm_lang['reputation'] and a rank title, and ultimately look (in enUS) like: 
	--		"Reputation with Guild is |cFF527001Honored (%%c/%%m)|r".
	--	%%c and %%m are replaced with the current and maximum reputation counts, respectively,  for the current reputation rank.
	--	To change the rank colors or titles, use the overrides below in the form of  '|cFF527001Honoured (%%c/%%m)|r'
	-- 	Default male hated: "|cFFA75219" .. getglobal("FACTION_STANDING_LABEL1") .. " (%%c/%%m)|r"
	tm_lang['malerank1'] 				= nil 									-- Hated, male override
	tm_lang['malerank2'] 				= nil 									-- Hostile, male override
	tm_lang['malerank3'] 				= nil 									-- Unfriendly, male override
	tm_lang['malerank4'] 				= nil 									-- Neutral, male override
	tm_lang['malerank5'] 				= nil 									-- Friendly, male override
	tm_lang['malerank6'] 				= nil 									-- Honored, male override
	tm_lang['malerank7'] 				= nil 									-- Revered, male override
	tm_lang['malerank8'] 				= nil 									-- Exalted, male override
	tm_lang['femalerank1'] 				= nil 									-- Hated, female override
	tm_lang['femalerank2'] 				= nil 									-- Hostile, female override
	tm_lang['femalerank3'] 				= nil 									-- Unfriendly, female override
	tm_lang['femalerank4'] 				= nil 									-- Neutral, female override
	tm_lang['femalerank5'] 				= nil 									-- Friendly, female override
	tm_lang['femalerank6'] 				= nil 									-- Honored, female override
	tm_lang['femalerank7'] 				= nil 									-- Revered, female override
	tm_lang['femalerank8'] 				= nil 									-- Exalted, female override

	-- Checkbuttons on main panel
	tm_lang['optionspanetitle']			=	'Options'
	tm_lang['chkverbose1tip'] 			= 	'Verbose enable\nAllow TabardMaster to post status messages such as tabard and gear swaps into the chat window.'
	tm_lang['chkverbose1text']	 		= 	'|cffffd200Report changes made by TabardMaster into the chat window|r'
	tm_lang['chkverbose2tip'] 			= 	'Exalted popups\nAllows TabardMaster to create popup windows such as when a reputation achieves exalted level.'
	tm_lang['chkverbose2text'] 			= 	'|cffffd200Allow TabardMaster to create popups|r'
	tm_lang['chkquesttip'] 				= 	'Guild reputation boost\nWear a guild tabard when finishing a quest to boost your guild reputation.  (Priority is epic, rare, common)'
	tm_lang['chkquesttext'] 			= 	'|cffffd200Wear a guild tabard when completing a quest.|r'
	tm_lang['chkzonetip'] 				= 	'Region changes\nChange your tabard when moving between regions in same world zone.'
	tm_lang['chkzonetext'] 				= 	'|cffffd200Swap tabard when changing regions|r'
	tm_lang['chktracker1tip'] 			= 	'Auto reputation bar\nThe reputation bar will change to the faction you are currently championing.'
	tm_lang['chktracker1text'] 			= 	'|cffffd200Change reputation bar to match tabard worn|r'
	tm_lang['chktracker2tip'] 			= 	'Restrict reputation bar\nRestrict the reputation bar to show only when wearing a tabard that champions a faction.'
	tm_lang['chktracker2text'] 			= 	'|cffffd200Hide reputation bar if not wearing a reputation tabard|r'
	tm_lang['chkminimaptip']			=	'Minimap button\nShow an icon for TabardMaster along with the other minimap icons.'
	tm_lang['chkminimaptext']			=	'|cffffd200Show a minimap button|r'
	tm_lang['chktexturetip']			=	'Tabard-O-Matic\nView tabard icons (in menus) as the tabards really look, or use their generic look'
	tm_lang['chktexturetext']			=	'|cffffd200Use custom tabard textures in menus|r'
	tm_lang['chkwearpvptip']			=	'PvP Gear\nWear your PvP gear and/or tabard when your PvP status is active in PvE zones.'
	tm_lang['chkwearpvptext']			=	'|cffffd200Wear PvP tabard and/or gear when flagged PvP|r'

	
-- Instances panel
	-- panel title & subtitle
	tm_lang['instancepaneltitle']		= 	'Instances'
	tm_lang['instancepanelsubtitle']	= 	"|cff7f7f00Select a tabard for each expansion's instances and maximize your reputation gains|r"
	-- the 'pick tabard' buttons
	tm_lang['instancebutton'] 			= 	'Select'
	-- %t is replaced with tabard name, tabard category, or a mode
	tm_lang['D60Tabard'] 				= 	'|cffffd200Classic dungeons:|r %t'
	tm_lang['D70Tabard'] 				= 	'|cffffd200Burning Crusades dungeons:|r %t'
	tm_lang['D80Tabard'] 				= 	'|cffffd200Lich King dungeons:|r %t'
	tm_lang['D85Tabard'] 				= 	'|cffffd200Cataclysm dungeons:|r %t'
	tm_lang['D90Tabard'] 				= 	'|cffffd200Mists of Pandaria dungeons:|r %t'
	tm_lang['D100Tabard'] 				= 	'|cffffd200Warlords of Draenor dungeons:|r %t'
	tm_lang['D110Tabard'] 				= 	'|cffffd200Legion dungeons:|r %t'
	tm_lang['D120Tabard'] 				= 	'|cffffd200Battle for Azeroth dungeons:|r %t'
	
	
-- GearMaster panel
	-- panel title & subtitle
	tm_lang['gearpaneltitle'] 			= 	'GearMaster'
	tm_lang['gearpanelsubtitle']	 	= 	'|cff7f7f00Change equipment sets based on location or instance|r'
	-- Individual entries for every situation; note that the buttons use the Instance panel's button entry.  %t will be replaced by a gearset name 
	--	or the 'donotchangegear' entry below.
	tm_lang['soloGear']					=	'|cffffd200Solo gearset:|r %t'
	tm_lang['cityGear']					=	'|cffffd200City gearset:|r %t'
	tm_lang['partyGear']				=	'|cffffd200Dungeon gearset:|r %t'
	tm_lang['raidGear']					=	'|cffffd200Raiding gearset:|r %t'
	tm_lang['pvpGear']					=	'|cffffd200PvP gearset:|r %t'
	tm_lang['homeGear']					=	'|cffffd200Garrison / Class Hall gearset:|r %t'
	-- replaces a gearset name if user doesn't want a gearset change
	tm_lang['donotchangegear']			=	'Gear set will not be changed'
	-- the LFG panel needs an explanation
	tm_lang['lfgInfo']					=	"Pick a role appropriate equipment set to wear when entering a dungeon, raid, or scenario using the LFG queues.  Scenarios use the 'NONE' gearset.  LFG gearsets take priority over the instance gearsets above."
	--	the checkbox needs some descriptive text and a tooltip	
	tm_lang['chkLFGroletip'] 			= 	'Looking For Group\nSwap your gear when entering a LFG instance'
	tm_lang['chkLFGroletext']			= 	'Change gearsets when a LFG queue activates'
	-- Entries for the LFG roles; %t will be replaced by a gearset name or the "nogear" entry above
	tm_lang['lfgpanetitle']				=	'LFG Gear changes'
	tm_lang['lfgTANK']					=	INLINE_TANK_ICON .. ' LFG |cffff0000TANK|r gearset: %t'
	tm_lang['lfgHEALER']				=	INLINE_HEALER_ICON .. ' LFG |cff00ff00HEALER|r gearset: %t'
	tm_lang['lfgDAMAGER']				=	INLINE_DAMAGER_ICON .. ' LFG |cff0000ffDAMAGER|r gearset: %t'
	tm_lang['lfgNONE']					=	factionIcon .. 'LFG |cffffffffNONE|r gearset: %t'
	

-- Advanced panel (Still in development!)
	tm_lang['advancedpaneltitle'] 		= 	'Advanced Options'
	tm_lang['advancedpanelsubtitle'] 	= 	'|cff7f7f00Change advanced settings|r'

	tm_lang['infopanetitle']		 	= 	'Info Panel'
	tm_lang['timerpanetitle']		 	= 	'Timers'
	
	tm_lang['delayZoneChangesTooltip']	=	'Time (in seconds) to delay between a zone change and TabardMaster\'s responding.'
	tm_lang['delayZoneChangesSingle']	=	'Delay zone changes %s second'
	tm_lang['delayZoneChangesPlural']	=	'Delay zone changes %s seconds'
	tm_lang['delayZoneChangesOff']		=	'Zone changes are not delayed'
	
	tm_lang['blockZoneChangesTooltip']	=	'Time (in seconds) to block subsequent zone change actions.'
	tm_lang['blockZoneChangesSingle']	=	'Block zone changes %s second'
	tm_lang['blockZoneChangesPlural']	=	'Block zone changes %s seconds'
	tm_lang['blockZoneChangesOff']		=	'Zone changes are not blocked'

	tm_lang['delayReputationChangesTooltip']=	'Time (in seconds) to delay between a faction reputation changing and TabardMaster\'s responding.'
	tm_lang['delayReputationChangesSingle']	=	'Delay reputation changes %s second'
	tm_lang['delayReputationChangesPlural']	=	'Delay reputation changes %s seconds'
	tm_lang['delayReputationChangesOff']	=	'Reputation changes are not delayed'

	tm_lang['blockReputationChangesTooltip']=	'Time (in seconds) to block subsequent faction reputation changes.'
	tm_lang['blockReputationChangesSingle']	=	'Block reputation changes %s second'
	tm_lang['blockReputationChangesPlural']	=	'Block reputation changes %s seconds'
	tm_lang['blockReputationChangesOff']	=	'Reputation updates are not blocked'

	
-- About panel
	-- panel title
	tm_lang['aboutpaneltitle'] 			= 	'About'
	-- individual lines, arranged as table since 106 (the line1 ... line10 entries also work)
	tm_lang['iofAboutPanel'] 			= 	{
											'Version: %version',
											"Author: Genrall of US-Ravencrest's Disillusioned guild",
											'English translation: Genrall',
											'Category: Equipment Management,',
											'',
											'Development Forum: http://disillusioned.x10host.com/forum/',
											'',
											'Curse Website: http://www.curse.com/addons/wow/tabardmaster',
											'Curse Forum: http://wow.curseforge.com/addons/tabardmaster/forum/',
											'',
											'"|cFF0080FFThose flying rabbits stole my knife|r" - thanks, Dad."',
											}
											
											
-- Modes and alternate entries used in setDisplay()
	-- tabard decoding error; usually it's caused by unavailable UI data (such as forcing a wrong faction tabard.  Which I never did.)
	--tm_lang['nodecode'] 				= 	"|cff800000TabardMaster problem: \"%t\" cannot be decoded at this time|r"
	-- tabard will not be changed
	tm_lang['donotchangetabard'] 		= 	'Tabard will not be changed'
	-- wear no tabard
	tm_lang['notabard'] 				= 	'Do not wear a tabard'
	-- the various modes
	tm_lang['modeguild']				=	'Wear a randomly chosen guild tabard'
	tm_lang['moderandom'] 				= 	'Wear a tabard chosen at random'
	tm_lang['modeauto'] 				= 	'Wear the most appropriate tabard'
	tm_lang['modeclosest'] 				= 	'Champion the faction closest to exalted'
	tm_lang['modefurthest'] 			= 	'Champion the faction furthest from exalted'
	tm_lang['unavailable'] 				= 	'Unavailable at your current level'  		-- text when option is disabled due to player level being too low
	tm_lang['modecustom']				=	'Wear tabard from custom tabard set %%e'	-- %%e gets replaced with custom tabard set name
	-- tabard categories
	tm_lang['guild']					=	'A random guild tabard'
	tm_lang['cities'] 					= 	'Champion a random city'
	tm_lang['arena'] 					= 	'Champion a random PvP faction'
	tm_lang['misc'] 					= 	'A random non-factioned tabard'
	tm_lang['D70tabards'] 				= 	'Random Burning Crusades faction tabard'
	tm_lang['D80tabards'] 				= 	'Random Lich King faction tabard'
	tm_lang['D85tabards'] 				= 	'Random Cataclysm faction tabard'
	tm_lang['D90tabards'] 				= 	'Random Mists of Pandaria faction tabard'
	tm_lang['D100tabards'] 				= 	'Random Warlords of Draenor faction tabard'
	tm_lang['D110tabards'] 				= 	'Random Legion faction tabard'
	tm_lang['D120tabards'] 				= 	'Random Battle for Azeroth faction tabard'

-- Entries for all the popup menus, most renamed 106
--[[ These are obsolete
	tm_lang['menuTitleTabard'] 			= 	'Select a tabard to wear'
	tm_lang['menuTitleCategory']		= 	'Select a tabard category'
	tm_lang['menuTitleGear'] 			= 	'Select equipment set'
	tm_lang['menuTitleMinimap']			=	'Quick change menu'
	-- menu headers (start of section)
	tm_lang['menuHdrInstance']			=	'Instance tier tabards'
	tm_lang['menuHdrCity']				=	'City tabards'
	tm_lang['menuHdrOther']				=	'All other tabards'
	tm_lang['menuHdrTabards']			=	'Specific tabards'
	tm_lang['menuHdrGear']				=	'Equipment sets'
	tm_lang['menuHdrCustom']			=	'Custom tabard categories'
	tm_lang['menuHdrAction']			=	'Special modes'
	-- menu actions and modes
	tm_lang['menuActionAuto']			=	'Pick most appropriate tabard'
	tm_lang['menuActionClosest']		=	'Closest to exalted'
	tm_lang['menuActionFurthest']		=	'Furthest from exalted'
	tm_lang['menuActionRandom']			=	'Random tabard'
	tm_lang['menuActionNoGear']			=	'Do not change gear set'
	-- tabard categories
	tm_lang['menuCategoryGuild']		=	'A random guild tabard'
	tm_lang['menuCategoryCities'] 		= 	'Champion a random city'
	tm_lang['menuCategoryArena'] 		= 	'Random PvP faction tabard'
	tm_lang['menuCategoryMisc'] 		= 	'A random non-factioned tabard'
	tm_lang['menuCategoryD70tabards'] 	= 	'A random Burning Crusades faction tabard'
	tm_lang['menuCategoryD80tabards'] 	= 	'Champion a random Lich King faction'
	tm_lang['menuCategoryD85tabards'] 	= 	'Champion a random Cataclysm faction'
	tm_lang['menuCategoryD90tabards'] 	= 	'A random Mists of Pandaria faction tabard'
	tm_lang['menuCategoryD100tabards'] 	= 	'A random Warlords of Draenor faction tabard'
	tm_lang['menuCategoryD110tabards'] 	= 	'A random Legion faction tabard'
]]	
	
-- Menu entries (new versions)
	-- used only in vTabard() and will probably go away
	tm_lang['menuActionNoTabard']		=	'No tabard'
	tm_lang['menuActionNoChange']		=	'Do not change tabard'

	-- miscellaneous entries
	tm_lang['menuIndent']				=	'  '								-- indent selectable entries a little

	-- 'options' menu segments
	tm_lang['menuOptionTitle'] 			= "TabardMaster Quick Change Menu"
	tm_lang['menuOptionGroup'] 			= "Quick Change Options"
	tm_lang['menuOptionLock'] 			= "Disable tabard & gear changes"
	tm_lang['menuOptionSwapTabards']	= "Enable tabard changes"
	tm_lang['menuOptionSwapGear'] 		= "Enable gear changes"
	
	-- 'tabard' menu segments
	tm_lang['menuTabardPresets'] 		= 'Tabard Presets'
	tm_lang['menuTabardQuick'] 			= "Quick Change Tabards"
	tm_lang['menuTabardSingle']			= "Individual Tabards"
	tm_lang['menuTabardRemove'] 		= 'Remove tabard'
	tm_lang['menuTabardNoChange']		= "Don't change tabard"
	tm_lang['menuTabardRandom']			= "Wear a random tabard"
	tm_lang['menuTabardAuto']			= "Auto pick tabard"
	tm_lang['menuTabardClosest']		= "Closest to exalted"
	tm_lang['menuTabardFurthest']		= "Furthest from exalted"
	tm_lang['menuTabardFaction']		= "Emphasize faction"
	tm_lang['menuTabardSelect']			= "Tabard Selection Menu"
	-- tabard categories have been un-implemented
	--tm_lang['menuTabardCategoryGuild']	=	'A random guild tabard'
	--tm_lang['menuTabardCategoryCities'] 	= 	'Champion a random city'
	--tm_lang['menuTabardCategoryArena']	= 	'Random PvP faction tabard'
	--tm_lang['menuTabardCategoryMisc'] 	= 	'A random non-factioned tabard'
	--tm_lang['menuTabardCategoryD70'] 		= 	'A random Burning Crusades faction tabard'
	--tm_lang['menuTabardCategoryD80'] 		= 	'Champion a random Lich King faction'
	--tm_lang['menuTabardCategoryD85'] 		= 	'Champion a random Cataclysm faction'
	--tm_lang['menuTabardCategoryD90'] 		= 	'A random Mists of Pandaria faction tabard'
	--tm_lang['menuTabardCategoryD100'] 	= 	'A random Warlords of Draenor faction tabard'
	--tm_lang['menuTabardCategoryD110'] 	= 	'A random Legion faction tabard'
	
	-- 'gear' menu segments
	tm_lang['menuGearQuick'] 			= "Quick Change Gear"
	tm_lang['menuGearSingle'] 			= "Individual Gear sets"
	tm_lang['menuGearSelect']			= "Gearset Selection Menu"
	
	-- 'other' menu segments
	tm_lang['menuOtherTitle'] 			= 	'Other Actions'
	tm_lang['menuOtherCancel']			= 	'Cancel'							-- cancel the menu

	
	-- Tooltip entry for the minimap 
	tm_lang['mmTooltip']				=	"Left-click for quick-change menu (or drag to move)\nRight-click for options."
	tm_lang['Alliance Vanguard']		=	'Champion the Alliance Vanguard'
	tm_lang['Horde Expedition']			=	'Champion the Horde Expedition'

	-- LDB tooltip
	tm_lang['Left Click']				= 'Left Click'
	tm_lang['Right Click']				= 'Right Click'
	tm_lang[' for quick change menu']	= ' for quick change menu'
	tm_lang[' for options']				= ' for options'
	
	-- info panel tooltip
	tm_lang['infopanelmove']			= '|cffff8040Shift + Left mouse|r to move'
	tm_lang['infopanelsize']			= '|cffff8040Shift + Left mouse|r to size'

	-- misc
	tm_lang['none']						= 'none'

-------------------------------------------------------------------------
-- End of default language entries
-------------------------------------------------------------------------

local locale = GetLocale()
-- Translation notes: the non English translations below were exported from Curse in the AceLocale format & batch
-- converted to conform.  Thanks go to the individual translators; recognition below.  (Badly outdated!)

if locale == 'enUS' then -- American english (what should really be "enGB" clients will return "enUS", too)
	-- change custom translations here ...
end

-- Need to change these to their respective languages instead of relying on the default values
if locale == "deDE" then -- German
	-- place custom translations here ...
end

if locale == "esES" then -- Spanish (Spain)
	-- place custom translations here ...
end

if locale == "esMX" then -- Spanish (Mexico)
	-- place custom translations here ...
end

if locale == "frFR" then -- French
-- this is the (incomplete) French version of the translations, courtesy of curse user Mips
	tm_lang['arena'] = "Un tabard JCJ al\\195\\169atoire" -- Needs review
	tm_lang['city1'] = "ville" -- Needs review
-- 	tm_lang['city2'] = ""
	tm_lang['cities'] = "Un tabard de ville al\\195\\169atoire" -- Needs review  Alatoire 
-- 	tm_lang['citytabard'] = ""
-- 	tm_lang['D60dungeons'] = ""
-- 	tm_lang['D70dungeons'] = ""
	tm_lang['D70tabards'] = "Tabard de faction de Burning Crusades al\\195\\169atoire" -- Needs review
-- 	tm_lang['D80dungeons'] = ""
	tm_lang['D80tabards'] = "Tabard de faction de Lich King al\\195\\169atoire" -- Needs review
-- 	tm_lang['D85dungeons'] = ""
	tm_lang['D85tabards'] = "Tabard de faction de Cataclysm al\\195\\169atoire" -- Needs review
-- 	tm_lang['D90dungeons'] = ""
	tm_lang['D90tabards'] = "Tabard de faction de Mists of Pandaria al\\195\\169atoire" -- Needs review
	tm_lang['disabled'] = "TabardMaster est actuellement d\\195\\169sactiv\\195\\169" -- Needs review
-- 	tm_lang['donotchange'] = ""
	tm_lang['fullbags'] = "|cffffff78TabardMaster: |cff9f006fImpossible de retirer le tabard, sacs plein|r" -- Needs review
-- 	tm_lang['guild'] = ""
	tm_lang['help'] = "aide"
	tm_lang['helptext'] = "TabardMaster accepte les commandes suivantes:\\n\\\"/tm s\\\" ou \\\"/tm seul\\\" pour \\195\\169quiper le tabard 'en solo',\\n\\\"/tm d\\\" ou \\\"/tm dongeon\\\" pour \\195\\169quiper le tabard 'dongeon',\\n\\\"/tm r\\\" ou \\\"/tm raid\\\" pour \\195\\169quiper le tabard 'raid', and\\n\\\"/tm p\\\" ou \\\"/tm jcj\\\"pour \\195\\169quiper le tabard JCJ.\\n\\\"/tm al\\195\\169atoire\\\" \\195\\169quipera un tabard al\\195\\169atoire de l'inventaire,\\n\\\"/tm (nom de la cat\\195\\169gorie)\\\" \\195\\169quipera un tabard al\\195\\169atoirement de cette cat\\195\\169gorie,\\n\\\"/tm\\\" affiche les options.\\n\\\"/tm q\\\" ou \\\"/tm silencieux\\\" bascule le mode silencieux on/off,\\n\\\"/tm off\\\" et \\\"/tm on\\\" d\\195\\169sactive et active TabardMaster, et \\\"/tm o\\\" d\\195\\169sactive ou active TabardMaster, et\\n\\\"/tm debug\\\" bascule le mode debug." -- Needs review
-- 	tm_lang['instancebutton'] = ""
-- 	tm_lang['line1'] = ""
 	tm_lang['line3'] = "Traduction franaise par Mips"
-- 	tm_lang['line4'] = ""
-- 	tm_lang['line5'] = ""
-- 	tm_lang['line6'] = ""
-- 	tm_lang['line7'] = ""
-- 	tm_lang['lockout'] = ""
-- 	tm_lang['mbox_message1'] = ""
	tm_lang['mbox_message2'] = "\\nLes groupes de tabards de TabardMaster doivent \\195\\170tre r\\195\\169initialis\\195\\169s\\n" -- Needs review
-- 	tm_lang['mbox_message3'] = ""
-- 	tm_lang['menuAuto'] = ""
-- 	tm_lang['menuClosest'] = ""
-- 	tm_lang['menuColor'] = ""
-- 	tm_lang['menuFurthest'] = ""
	tm_lang['menuLeaveTabard'] = "Ne pas changer de tabard" -- Needs review
-- 	tm_lang['menuNoTabard'] = ""
-- 	tm_lang['menuRandomtabard'] = ""
	tm_lang['menutitlecategory'] = "S\\195\\169lectionnez une cat\\195\\169gorie de tabard" -- Needs review
	tm_lang['menutitletabard'] = "S\\195\\170lectionnez un tabard \\195\\160 \\195\\170quiper" -- Needs review
	tm_lang['misc'] = "Un tabard al\\195\\169atoire" -- Needs review
-- 	tm_lang['modeauto'] = ""
-- 	tm_lang['modeclosest'] = ""
-- 	tm_lang['modefurthest'] = ""
	tm_lang['modeguild'] = "Un tabard de guilde al\\195\\169atoire" -- Needs review
-- 	tm_lang['moderandom'] = ""
-- 	tm_lang['modeunavailable'] = ""
	tm_lang['nodecode'] = "|cff800000Tabard %t ne peut pas \\195\\170tre d\\195\\169cod\\195\\169 pour l'instant|r" -- Needs review
	tm_lang['noreputation'] = "Aucun gain de r\\195\\169putation par le tabard" -- Needs review
	tm_lang['notabard'] = "|cffd20000Aucun tabard|r" -- Needs review
	tm_lang['p1'] = "jcj" -- Needs review
-- 	tm_lang['p2'] = ""
-- 	tm_lang['panel1name'] = ""
-- 	tm_lang['panel1subtitle'] = ""
-- 	tm_lang['panel2name'] = ""
	tm_lang['pickcategorybutton'] = "|cffdeaf25Choix cat\\195\\169gorie|r" -- Needs review
	tm_lang['picktabardbutton'] = "|cffdeaf25Choix tabard|r" -- Needs review
	tm_lang['pvptabard'] = "|cffffd200Tabard en JCJ:|r %t"
	tm_lang['q1'] = "silencieux" -- Needs review
-- 	tm_lang['q2'] = ""
	tm_lang['questtext'] = "Equiper un tabard de guilde lors de la remise de qu\\195\\170te" -- Needs review
	tm_lang['questtooltip'] = "S\\195\\169lectionner pour activer le port temporaire du tabard de guilde lors de la remise de qu\\195\\170te" -- Needs review
	tm_lang['r1'] = "raid" -- Needs review
-- 	tm_lang['r2'] = ""
	tm_lang['r3'] = "al\\195\\169atoire" -- Needs review
-- 	tm_lang['r4'] = ""
	tm_lang['raidtabard'] = "|cffffd200Tabard en raid:|r %t"
--	tm_lang['randomtabard'] = "|cff0080ffTabard al\\195\\169atoire|r" -- Needs review
-- 	tm_lang['ready'] = ""
	tm_lang['s1'] = "seul" -- Needs review
-- 	tm_lang['s2'] = ""
-- 	tm_lang['seperatorAction'] = ""
-- 	tm_lang['seperatorCity'] = ""
-- 	tm_lang['seperatorColor'] = ""
-- 	tm_lang['seperatorCustom'] = ""
-- 	tm_lang['seperatorInstance'] = ""
-- 	tm_lang['seperatorOther'] = ""
-- 	tm_lang['seperatorTabards'] = ""
	tm_lang['solotabard'] = "|cffffd200Tabard en solo:|r %t"
	tm_lang['subtitle'] = "\"Cliquez sur '\" .. tm_lang[\"picktabardbutton\'] .. \"' pour afficher une liste de tabard qui peuvent \\195\\170tre port\\195\\169s quand vous \\195\\170tes dans ce type de groupe; Cliquez sur '\" .. tm_lang[\"pickcategorybutton\'] .. \"' pour afficher une liste de cat\\195\\169gories de tabard de laquelle un tabard sera s\\195\\169lectionn\\195\\169. Pour ne porter aucun tabard dans un type de groupe, s\\195\\169lectionnez '\" .. tm_lang[\"notabard\'] .. \"'.\"" -- Needs review
-- 	tm_lang['t1'] = ""
-- 	tm_lang['t2'] = ""
-- 	tm_lang['t3'] = ""
	tm_lang['tabardchange'] = "|cffffff78TabardMaster: Changement de tabard:|r %t" -- Needs review
	tm_lang['tabardmissing'] = "|cffffd200TabardMaster: |cff9f006fTabard|r %t |cff9f006fabsent de l'inventaire|r" -- Needs review
	tm_lang['tabardremoved'] = "|cffffff78TabardMaster: Retire le tabard|r" -- Needs review
-- 	tm_lang['title'] = ""
-- 	tm_lang['trackertext'] = ""
-- 	tm_lang['trackertooltip'] = ""
	tm_lang['verbosetext'] = "Notifier les changements de tabard effectu\\195\\169 par TabardMaster dans la fen\\195\\170tre de discussion" -- Needs review
	tm_lang['verbosetooltip'] = "S\\195\\169lectionner pour activer la notification de changement de tabard"
-- 	tm_lang['z1'] = ""
-- 	tm_lang['z2'] = ""
-- 	tm_lang['zonetext'] = ""
-- 	tm_lang['zonetooltip'] = ""
end

if locale == "itIt" then -- Italian - coming soon to an install near you
	-- place custom translations here ...
end

if locale == "koKR" then -- Korean
	-- place custom translations here ...
end

if locale == "ptBR" then -- Brazilian Portugese  (It's all Greek to me!)
	-- place custom translations here ...
end

if locale == "ruRU" then -- Russian
	-- place custom translations here ...
end

if locale == "zhCN" then -- Chinese (simplified)
-- this is the (incomplete) Chinese simplified version of the translations, courtesy of curse user wowuicn
-- 	tm_lang['arena'] = ""
-- 	tm_lang['c1'] = ""
-- 	tm_lang['c2'] = ""
-- 	tm_lang['cities'] = ""
-- 	tm_lang['citytabard'] = ""
-- 	tm_lang['D60dungeons'] = ""
-- 	tm_lang['D70dungeons'] = ""
	tm_lang['D70tabards'] = "\233\154\143\230\156\186\231\135\131\231\131\167\231\154\132\232\191\156\231\168\139\229\163\176\230\156\155\230\136\152\232\162\141" -- Needs review
-- 	tm_lang['D80dungeons'] = ""
	tm_lang['D80tabards'] = "\233\154\143\230\156\186\229\183\171\229\166\150\231\142\139\228\185\139\230\128\146\229\163\176\230\156\155\230\136\152\232\162\141" -- Needs review
-- 	tm_lang['D85dungeons'] = ""
	tm_lang['D85tabards'] = "\233\154\143\230\156\186\229\164\167\229\156\176\231\154\132\232\163\130\229\143\152\229\163\176\230\156\155\230\136\152\232\162\141" -- Needs review
-- 	tm_lang['D90dungeons'] = ""
	tm_lang['D90tabards'] = "\233\154\143\230\156\186\231\134\138\231\140\171\228\186\186\228\185\139\232\176\156\229\163\176\230\156\155" -- Needs review
	tm_lang['disabled'] = "TabardMaster \229\189\147\229\137\141\228\184\186\231\166\129\231\148\168" -- Needs review
-- 	tm_lang['donotchange'] = ""
	tm_lang['fullbags'] = "|cffffff78TabardMaster: |cff9f006f\228\184\141\232\131\189\231\167\187\233\153\164\230\136\152\232\162\141, \232\131\140\229\140\133\229\183\178\230\187\161|r" -- Needs review
-- 	tm_lang['guild'] = ""
-- 	tm_lang['help'] = ""
-- 	tm_lang['helptext'] = ""
-- 	tm_lang['instancebutton'] = ""
-- 	tm_lang['line1'] = ""
-- 	tm_lang['line3'] = ""
-- 	tm_lang['line4'] = ""
-- 	tm_lang['line5'] = ""
-- 	tm_lang['line6'] = ""
-- 	tm_lang['line7'] = ""
-- 	tm_lang['lockout'] = ""
-- 	tm_lang['mbox_message1'] = ""
	tm_lang['mbox_message2'] = "\\nTabardMaster\231\154\132\230\136\152\232\162\141\229\136\134\231\187\132\233\156\128\232\166\129\232\162\171\233\135\141\231\189\174\\n" -- Needs review
-- 	tm_lang['mbox_message3'] = ""
-- 	tm_lang['menuAuto'] = ""
-- 	tm_lang['menuClosest'] = ""
-- 	tm_lang['menuColor'] = ""
-- 	tm_lang['menuFurthest'] = ""
	tm_lang['menuLeaveTabard'] = "\228\184\141\232\166\129\230\148\185\229\143\152\230\136\152\232\162\141" -- Needs review
-- 	tm_lang['menuNoTabard'] = ""
-- 	tm_lang['menuRandomtabard'] = ""
	tm_lang['menutitlecategory'] = "\233\128\137\230\139\169\228\184\128\228\184\170\230\136\152\232\162\141\229\136\134\231\177\187" -- Needs review
	tm_lang['menutitletabard'] = "\233\128\137\230\139\169\228\184\128\228\184\170\232\166\129\231\169\191\228\184\138\231\154\132\230\136\152\232\162\141" -- Needs review
	tm_lang['misc'] = "\228\184\128\228\184\170\233\154\143\230\156\186\231\154\132\230\157\130\233\161\185\230\136\152\232\162\141" -- Needs review
-- 	tm_lang['modeauto'] = ""
-- 	tm_lang['modeclosest'] = ""
-- 	tm_lang['modefurthest'] = ""
	tm_lang['modeguild'] = "\228\184\128\228\184\170\233\154\143\230\156\186\229\133\172\228\188\154\230\136\152\232\162\141" -- Needs review
-- 	tm_lang['moderandom'] = ""
-- 	tm_lang['modeunavailable'] = ""
	tm_lang['nodecode'] = "|cff800000\230\136\152\232\162\141 %t \228\184\141\232\131\189\232\162\171\232\167\163\231\160\129|r" -- Needs review
	tm_lang['noreputation'] = "\230\178\161\230\156\137\228\187\142\230\136\152\232\162\141\232\142\183\229\190\151\229\163\176\230\156\155" -- Needs review
	tm_lang['notabard'] = "|cffd20000\230\178\161\230\156\137\230\136\152\232\162\141|r" -- Needs review
-- 	tm_lang['p1'] = ""
-- 	tm_lang['p2'] = ""
-- 	tm_lang['panel1name'] = ""
-- 	tm_lang['panel1subtitle'] = ""
-- 	tm_lang['panel2name'] = ""
	tm_lang['pickcategorybutton'] = "\233\128\137\229\143\150\229\136\134\231\177\187" -- Needs review
	tm_lang['picktabardbutton'] = "\233\128\137\229\143\150\230\136\152\232\162\141" -- Needs review
	tm_lang['pvptabard'] = "|cffffd200PvP \230\136\152\232\162\141:|r %t" -- Needs review
-- 	tm_lang['q1'] = ""
-- 	tm_lang['q2'] = ""
	tm_lang['questtext'] = "\229\189\147\229\174\140\230\136\144\228\187\187\229\138\161\230\151\182\231\169\191\228\184\138\229\133\172\228\188\154\230\136\152\232\162\141" -- Needs review
	tm_lang['questtooltip'] = "\233\128\137\230\139\169\230\157\165\229\144\175\231\148\168\229\156\168\228\186\164\228\187\187\229\138\161\230\151\182\228\184\180\230\151\182\230\141\162\228\184\138\229\133\172\228\188\154\230\136\152\232\162\141" -- Needs review
-- 	tm_lang['r1'] = ""
-- 	tm_lang['r2'] = ""
-- 	tm_lang['r3'] = ""
-- 	tm_lang['r4'] = ""
	tm_lang['raidtabard'] = "|cffffd200\229\155\162\233\152\159\230\136\152\232\162\141:|r %t" -- Needs review
--	tm_lang['randomtabard'] = "|cff0080ff\233\154\143\230\156\186\230\136\152\232\162\141|r" -- Needs review
-- 	tm_lang['ready'] = ""
-- 	tm_lang['s1'] = ""
-- 	tm_lang['s2'] = ""
-- 	tm_lang['seperatorAction'] = ""
-- 	tm_lang['seperatorCity'] = ""
-- 	tm_lang['seperatorColor'] = ""
-- 	tm_lang['seperatorCustom'] = ""
-- 	tm_lang['seperatorInstance'] = ""
-- 	tm_lang['seperatorOther'] = ""
-- 	tm_lang['seperatorTabards'] = ""
	tm_lang['solotabard'] = "|cffffd200\229\141\149\228\186\186\230\136\152\232\162\141:|r %t" -- Needs review
-- 	tm_lang['subtitle'] = ""
-- 	tm_lang['t1'] = ""
-- 	tm_lang['t2'] = ""
-- 	tm_lang['t3'] = ""
	tm_lang['tabardchange'] = "|cffffff78TabardMaster: \230\148\185\229\143\152\230\136\152\232\162\141\228\184\186|r %t" -- Needs review
	tm_lang['tabardmissing'] = "|cffffd200TabardMaster: |cff9f006f\230\136\152\232\162\141|r %t |cff9f006f\231\188\186\229\164\177|r" -- Needs review
	tm_lang['tabardremoved'] = "|cffffff78TabardMaster: \231\167\187\233\153\164\230\136\152\232\162\141|r" -- Needs review
-- 	tm_lang['title'] = ""
-- 	tm_lang['trackertext'] = ""
-- 	tm_lang['trackertooltip'] = ""
	tm_lang['verbosetext'] = "\229\156\168\232\129\138\229\164\169\230\161\134\228\184\173\230\138\165\229\145\138TabardMaster\229\175\185\230\136\152\232\162\141\231\154\132\230\148\185\229\143\152" -- Needs review
	tm_lang['verbosetooltip'] = "\233\128\137\230\139\169\230\157\165\229\144\175\231\148\168\230\136\152\232\162\141\230\148\185\229\143\152\231\154\132\230\138\165\229\145\138" -- Needs review
-- 	tm_lang['z1'] = ""
-- 	tm_lang['z2'] = ""
-- 	tm_lang['zonetext'] = ""
-- 	tm_lang['zonetooltip'] = ""
end

if locale == "zhTW" then -- Chinese (traditional)
	-- place custom translations here ...
end


-------------------------------------------------------------------------
-- Final prep; consolidate data in AboutPanel lines to own array
-------------------------------------------------------------------------
if not tm_lang['iofAboutPanel'] then
	tm_lang['iofAboutPanel'] = {}
	local line, i
	for i = 1, 10 do
		line = "line" .. i
		if tm_lang[line] then
			table.insert(tm_lang['iofAboutPanel'], tm_lang[line])
		end
	end
end

