----------------------------------------------------------------------
--
-- Lookups.lua - TabardMaster's lookup tables
--
-- See individual sections for each table's functionality.
--
----------------------------------------------------------------------


----------------------------------------------------------------------
--
-- tm_reputationXRef - TabardMaster's reputation lookup table
--
-- Used to convert a faction ID to it's tabard, plus hold a localized 
-- faction name, group type ID, current and previous reputation ranks, 
-- total accrued reputation with the faction, and current and maximum
-- reputation values for current reputation rank.  group entry is
-- currently unused and may be removed later.
--
-- Table is initialized with limited data for just the factions that 
-- can be championed with tabards and will be populated later with 
-- data for all factions.
--
-- 'Guild' tabard IDs are 69210, 69209, 5976
-- 'Faction' (allegiance) tabards are anything NOT D80 or D85.
--
----------------------------------------------------------------------
tm_reputationXRef = {
	['1168'] = {tabard = 'guild', group = 'guild'},								-- Guild

	['47'] 	 = {tabard = 45577, group = 'city'},								-- Ironforge 
	['54'] 	 = {tabard = 45578, group = 'city'},								-- Gnomeregan 
	['68'] 	 = {tabard = 45583, group = 'city'},								-- Undercity 
	['69'] 	 = {tabard = 45579, group = 'city'},								-- Darnassus 
	['72'] 	 = {tabard = 45574, group = 'city'},								-- Stormwind 
	['76']	 = {tabard = 45581, group = 'city'},								-- Orgrimmar 
	['81'] 	 = {tabard = 45584, group = 'city'},								-- Thunder Bluff 
	['530']  = {tabard = 45582, group = 'city'},								-- Darkspear Trolls 
	['911']  = {tabard = 45585, group = 'city'},								-- Silvermoon City 
	['930']	 = {tabard = 45580, group = 'city'},								-- Exodar 
	['1133'] = {tabard = 64884, group = 'city'},								-- Bilgewater Cartel 
	['1134'] = {tabard = 64882, group = 'city'},								-- Gilneas 
	['1352'] = {tabard = 83080, group = 'city'},								-- Huojin Pandaren 
	['1353'] = {tabard = 83079, group = 'city'},								-- Tushui Pandaren 

	['1037'] = {tabard = 'faction', group = 'faction'},							-- Alliance Vanguard (Header)
	['1052'] = {tabard = 'faction', group = 'faction'},							-- Horde Expedition (Header)
	['1090'] = {tabard = 43157, group = 'D80'},									-- Kirin Tor 
	['1091'] = {tabard = 43156, group = 'D80'},									-- The Wyrmrest Accord 
	['1098'] = {tabard = 43155, group = 'D80'},									-- Knights of the Ebon Blade 
	['1106'] = {tabard = 43154, group = 'D80'},									-- Argent Crusade 

	['1135'] = {tabard = 65905, group = 'D85'},									-- The Earthen Ring 
	['1158'] = {tabard = 65906, group = 'D85'},									-- Guardians of Hyjal 
	['1171'] = {tabard = 65907, group = 'D85'},									-- Therazane 
	['1172'] = {tabard = 65909, group = 'D85'},									-- Dragonmaw Clan 
	['1173'] = {tabard = 65904, group = 'D85'},									-- Ramkahen 
	['1174'] = {tabard = 65908, group = 'D85'},									-- Wildhammer Clan 
}


----------------------------------------------------------------------
--
-- tm_factionXFer - Tabard to factionId lookup table for tabards that 
--	champion a faction
--
-- (Essentially the reverse of above; table will be used for speed)
--
----------------------------------------------------------------------
tm_tabardXRef = {}
for factionId, data in pairs(tm_reputationXRef) do
	if type(data.tabard) == 'number' then
		tm_tabardXRef[tostring(data.tabard)] = tonumber(factionId)
	end
end
-- add the factionIds for guild tabards 
tm_tabardXRef['5976']	= 1168
tm_tabardXRef['69209']	= 1168
tm_tabardXRef['69210']	= 1168


----------------------------------------------------------------------
-- 
-- tm_raidFaction - Instance (raid) to faction converter
--
-- Used to show reputation bar for a raid faction; indexes are 
--	raid mapIds.
--
----------------------------------------------------------------------
tm_raidFaction = {
	["696"] = "749",			-- Molten Core grants Hydraxian Waterlords reputation
	["717"] = "609 910",		-- Ruins of Ahn'Qiraj grants Cenarian Circle & Brood of Nozdormu reputation
	["772"] = "609 910",		-- Ahn'Qiraj: The Fallen Kingdom (AKA Temple) grants Cenarian Circle & Brood of Nozdormu reputation
	["799"] = "967",			-- Karazhan grants The Violet Eye reputation
	["775"] = "990",			-- Hyjal Summit grants The Scale of the Sands reputation
	["796"] = "1012",			-- The Black Temple grants Ashtongue Deathsworn reputation
	["604"] = "1156", 			-- Icecrown Citadel grants The Ashen Verdict reputation
	["752"] = "1177", 			-- Baradin Hold grants Baradin's Wardens reputation
	["800"] = "1204", 			-- Firelands grants Avengers of Hyjal reputation
	["953"] = "1492", 			-- Siege of Orgrimmar shows Emperor Shaohao reputation 
} 


----------------------------------------------------------------------
--
-- tm_tabardGroup - TabardMaster's default tabard categories
--
-- these are the itemIDs of all known tabards, grouped into 
-- categories.  See AllTabards.txt for descriptions.
--
-- It it not recommended to add tabards into these categories as 
--	doing so may cause tabard selections to be incorrect in 'auto' 
--	mode.  Instead, create a custom tabard category in custom.lua
--	and select from that category instead.
--
-- To create alternate tabard categories in custom.lua
-- see http://wow.curseforge.com/addons/tabardmaster/forum/
--
----------------------------------------------------------------------

tm_tabardGroup = {
	-- the guild tabards spring collection, ordered by experience bonus ...
	['guild'] = 	'69210 69209 5976', -- "Renowned Guild Tabard" (epic), "Illustrious Guild Tabard" (rare), "Guild Tabard" (Normal)
	-- champion a city - all the city tabards
	['cities'] = '45574 45577 45578 45579 45580 45581 45582 45583 45584 45585 64882 64884 83079 83080',	
	-- pvp tabards
	['arena'] = '15196 15197 15198 15199 19031 19032 19160 19505 19506 20131 20132 36941 43349 45983 49052 49054 49086 51534 63378 63379 98162 101696 101697 103636 115972 127365 127366 127369 127371 147336 147337 147338 147339 149442 149443 149446 149447 149450 149451 163055',
	
	-- everything else ...
	['misc'] = '22999 23192 23705 23709 24344 25549 28788 31279 38309 38310 38311 38312 38313 38314 31404 31405 35279 35280 40643 43300 43348 46817 46818 46874 52252 86468 89196 104008 133670 156666 157756 157757 157758 157759',
	-- these are dungeon tabards
	['D70tabards'] = '23999 24004 31773 31774 31775 31776 31777 31778 31779 31780 31781 31804 32445 32828 35221', -- Burning Crusades
	['D80tabards'] = '43154 43155 43156 43157',	-- Lich King
	['D85tabards'] = '65904 65905 65906 65907 65908 65909',	-- Cataclysm
	['D90tabards'] = '89401 89784 89795 89796 89797 89798 89799 89800 95591 95592 97131',	-- Pandaria
	-- Draenor; slave tabard, Wrynn's Vanguard, Vol'jin's Spear, Stormwind, Orgrimmar, Frostwolf Tabard, Council of Exarchs, Arakkoa Outcasts, Steamwheedle "Preservation" Society, Laughing Skull Orcs, Sha'tari Defense, Saberstalkers Tabard, Order of the Awakened Tabard
	['D100tabards'] = '107897 115517 115518 118365 118372 119133 119135 119136 119137 119138 119140 128449, 128450',
	-- Legion; (Cropped) Scarlet Crusade, The Nightfallen, Highmountain Tribe, Court of Farondis, Dreamweavers, Valarjar, The Wardens, Dreamweavers, Armies of Legionfall, Army of the Light, Argussian Reach
	['D110tabards'] = '138429 140575 140576 140577 140578 140579 140580 140667 147205 152399 152559',
	-- Battle for Azeroth; 7th Legion, Proudmoore Admiralty, Order of Embers, Storm's Wake, Tortollan Seekers, Champions of Azeroth, The Honorbound, Zandalari Empire, Talanji's Expedition, Voldunai, Maghar Clans, Dark Iron
	['D120tabards'] = '160539 160540 160541 160542 160543 160544 160545 160546 160547 160548 161328 161329',
}


----------------------------------------------------------------------
--
-- tm_maps - TabardMaster's mapId mapping table
--
-- These are the mapIds of all zones, grouped into territories
-- 
-- See http://www.wowpedia.org/MapID for zone Ids
-- Alternatively, run this macro:
-- /run for mapId = 0, 1500 do i = GetMapNameByID(mapId);if i then print(mapId, "is zone", i);end;end
--
-- All we really need to keep track of, are PvE zones, world PvP zones, 
--	cities, and champion dungeons by level.  The addon can determine 
--	scenario, raid, pve and pvp zones on it's own through GetInstanceInfo() 
--	calls into the API.  Note that a "new" dungeon would be an unlisted 
--	zone with an instanceType of 'party', and a "new" raid would be just 
--	another 'raid' instanceType; raids are not separated by level, and 
--	scenarios are treated as dungeons.  This method, however,  allows for 
--	greater customization and finer control over which tabards and gearsets 
--	to wear for a given zone.
----------------------------------------------------------------------

-- Culled from multiple sources, including http://wow.gamepedia.com/MapID - this all chaned with client 8, see conversion table below

tm_maps = {
-- See mapId.txt for conversion of mapId to zone name

--[[ New UiMapIDs, cannot implement until all map IDs changed ]]
	--Stormwind City, Ironforge, Darnassus, The Exodar, Shrine of Seven Stars, Stormshield
	['allianceCities'] = '301 341 381 471 905 1009',
--	["allianceCities"] = "84, 87, 89, 103, 393 394, 622",
--	Orgrimmar, Thunder Bluff, Undercity, Silvermoon City, Shrine of Two Moons, Warspear
	['hordeCities'] = '321 362 382 480 903 1011',
--	["hordeCities"] = "85 86, 88, 90 998, 110, 391 392, 624",
--	neutral cities Shattrath City, Northrend Dalaran, Deadwind Pass Dalaran, Broken Isles Dalaran, Darkmoon Island
	-- NOTE: the 2 Pandarian Shrines do not generate a zone change event.
	['neutralCities'] = '481 504 924 1014',
--	["neutralCities"] = "111, 125 126, 501 502, 625 627 628 629, 407 408",

--[[ class halls, might add to neutralCities

Death Knight (Acherus) 			647 648
Demon Hunter (The Fel Hammer)	
Druid (Dreamgrove)				747
Hunter (Trueshot Lodge)			739
Mage (Hall of the Guardian)		734 735
Monk (Temple of Five Dawns)
Paladin (Sanctum of Light)
Priest (Netherlight Temple)		702
Rogue (Chamber of Shadows)		626
Shaman (The Maelstrom)			726 
Warlock (Dreadscar Rift) 		717 718
Warrior (Skyhold)				695

]]
	
	--['arenas'] = 'ALL arenas Id as -1, (generic world) so are represented internally as mapId 9000'
	-- Wintergrasp, Tol Barad, Ashran
	['PvP Zone'] = '501 708 978',
--	['PvP Zone'] = '123, 244 245 773 774, 588 589',
-- 	Battlegrounds (lvl 10) Arathi Basin, Warsong Gulch, (lvl 35) Eye of the Storm, (lvl 45) Alterac Valley, (lvl 65) Strand of the Ancients,
--		(lvl 71) Isle of Conquest, (lvl 85) The Battle for Gilneas, Twin Peaks, (lvl 90) Temple of Kotmogu, Silvershard Mines, Deepwind Gorge
--		(lvl 110) Battle for Blackrock Mountain, Seething Shore, Silithus Brawl, Hillsbrad Foothills (AKA Southshore VS Tarren Mill), Twin 
--		Peaks.  Missing: Alliance Airship, Cooking Impossible, Hackaton Race
	['Battlegrounds'] = '461 443 482 813 401 512 540 736 626 856 881 860 935',
--	['Battlegrounds'] = '93 837 844, 92 859, 112 397, 91, 128, 169, 275, 206, 417 449, 423, 519, 838, 907, 904, 623, 206',

	--Kamimdor PvE territories
	['Kalimdor'] = '4 9 11 13 41 42 43 61 81 101 121 141 161 181 182 201 241 261 281 464 476 539 606 607 677 678 679 720 772 795 851 888 889 890 891 894',
	
	--Eastern Kingdoms PvE territories
	['Eastern Kingdoms'] = '14 16 17 19 20 21 22 23 24 26 27 28 29 30 32 34 35 36 37 38 39 40 462 463 499 502 545 610 611 613 614 615 673 684 685 689 700 709 770 864 866 892 893 895',
	-- Classic raids; Molten Core, Ruins of Ahn'Qiraj, Blackwing Lair, Temple of Ahn'Qiraj
	['Classic Raids'] = '696 717 755 766',
	-- Classic dungeons; these champion no factions.  Blackfathom Deeps, Blackrock Depths, Blackrock Spire, Dire Maul, 
	--		Gnomeregan, Maraudon, Ragefire Chasm, Razorfen Downs, Razorfen Kraul, Stratholme, The Stockade, 
	--		The Temple of Atal'Hakkar, Uldaman, Wailing Caverns, Zul'Farrak,  Scarlet Monastery, 
	--		Scholomance(Old), Stratholme, Deeprun Tram 922 & Brawl'gar Arena 925.  Deadmines and Shadowfang Keep are listed under X85;
	-- 		Scarlet Halls, Scarlet Monastery, & Scholomance are listed under X90.
	['D60'] = '680 686 687 688 690 691 692 699 704 721 749 750 760 761 762 763 765 922 925',
	-- Classic dungeons requiring heroic mode to champion.  None.
	--['H60'] = '',

	--Outland PvE territories
	['Outland'] = '465 466 467 473 475 477 478 479',
--	Hellfire Peninsula, Zangarmarsh, Shadowmoon Valley, Blade's Edge Mountains, Nagrand, Terokkar Forest, Netherstorm
--	['Outland'] = '100, 102, 104, 105, 107, 108, 109',

	-- Outland raids; Hyjal Summit, Gruul's Lair, Magtheridon's Lair, Serpentshrine Cavern, The Eye, Sunwell Plateau, Black Temple, Karazhan	
	['Outland Raids'] = '775 776 779 780 782 789 796 799',
	-- Outland dungeons; The Shattered Halls, Auchenai Crypts, Sethekk Halls, 
	--		Shadow Labyrinth, The Blood Furnace, The Underbog, The Steamvault, The Slave Pens, The Botanica, 
	--		The Mechanar, The Arcatraz, Mana-Tombs, The Black Morass, Old Hillsbrad Foothills, Hellfire Ramparts, 
	--		Magisters' Terrace			
	['D70'] = '710 722 723 724 725 726 727 728 729 730 731 732 733 734 797 798',
	-- Outland dungeons requiring heroic mode to champion.  None.
	--['H70'] = '',
	
	--Northrend PvE territories
	['Northrend'] = '485 486 488 490 491 492 493 495 496 510 541',
	
--	Borean Tundra, Dragonblight, Grizzly Hills, Howling Fjord, Icecrown, Sholazar Basin, The Storm Peaks, Zul'Drak, Wintergrasp, Crystalsong Forest, Hrothgar's Landing
--	['Northrend'] = '114, 115, 116, 117, 118, 119, 120, 121, 123, 127, 170',
	
	-- Northrend raids; The Eye of Eternity, Ulduar, The Obsidian Sanctum, Vault of Archavon, Naxxramas, Trial of the Crusader, 
	--		Icecrown Citadel, The Ruby Sanctum, Onyxia's Lair
	['Northrend Raids'] = '527 529 531 532 535 543 604 609 718',
	-- Northrend dungeons that can be championed in any mode; Utgarde Pinnacle, The Culling of Stratholme, The Oculus, 
	--		Halls of Lightning, The Forge of Souls, Pit of Saron, & Halls of Reflection
	['D80'] = '521 524 525 528 601 602 603',
	-- Northrend dungeons requiring heroic mode to champion; The Nexus, Ahn'kahet: The Old Kingdom, Utgarde Keep, 
	--		Halls of Stone, Gundrak, Azjol-Nerub, Drak'Tharon Keep, The Violet Hold, Trial of the Champion, & The Nexus
	['H80'] = '520 522 523 526 530 533 534 536 542 803',

	-- Cataclysm PvE territories (including Darkmoon Island <- delete!)
	['Cataclysm'] = '544 605 640 683 737 748 751 823',
	--	Cataclysm raids: Baradin Hold, Blackwing Descent, The Bastion of Twilight, Throne of the Four Winds, Firelands, Dragon Soul
	['Cataclysm Raids'] = '752 754 758 773 800 824',
	-- Cataclysm dungeons that can be championed in any mode; Grim Batol, Halls of Origination
	['D85'] = '757 759',
	-- Cataclysm dungeons requiring heroic mode to champion; Zul'Gurub, Lost City of the Tol'vir, Blackrock Caverns, 
	--		Throne of the Tides, The Stonecore, The Vortex Pinnacle, Zul'Aman, Zul'Gurub, Well of Eternity, 
	--		Hour of Twilight, & End Time
	['H85'] = '697 747 753 767 768 769 781 793 816 819 820',
	-- special treatment instances: Deadmines & Shadowfang Keep are D60 in normal mode, D85 in heroic.
	['X85'] = '756 764',

	-- Pandaria PvE territories
	['Pandaria'] = '806 807 808 809 810 811 857 858 862 873 681 682 928 951 955 928 929 933',	
	-- Pandarian raids: Terrace of Endless Spring, Mogu'shan Vaults, Heart of Fear, Throne of Thunder, Siege of Orgrimmar
	['Pandaria Raids'] = '886 896 897 930 953',
	-- Scenarios; are treated as D90 in mapDecoder()
	-- Vale of Eternal Blossoms (Dark Heart of Pandaria), The Secrets of Ragefire, Dun Morogh (Blood in the Snow), Battle on the High Seas
--	['Pandaria Scenarios'] = '878 879 880 882 883 884 899 900 906 907 910 911 912 914 919 920 934 937 938 939 940',
	-- Pandaria dungeons that can be championed in any mode; Gate of the Setting Sun & Siege of Niuzao Temple
	['D90'] = '875 887',
	-- Pandaria dungeons requiring heroic mode to champion;
	--		Temple of the Jade Serpent, Stormstout Brewery, Shado-Pan Monastery, & Mogu'shan Palace
	['H90'] = '867 876 877 885',
	 -- Scarlet Halls, Scarlet Monastery, & Scholomance are D60 normal, D90 heroic
	['X90'] = '871 874 898',

	-- Warlords of Draenor PvE territories
	['Draenor'] = '941 945 946 947 948 949 950 962 970 971 973 974 975 976 980 981 982 986 990 991 992 1011',
	-- Warlords of Draenor raids; Highmaul, Blackrock Foundry, Hellfire Citadel
	['Draenor Raids'] = '994 988 1026',
	-- Warlords of Draenor scenarios
--	['Draenor Scenarios'] = '983',
	-- Warlords of Draenor dungeons
	--	Bloodmaul Slag Mines, Shadowmoon Burial Grounds, Auchindoun, Iron Docks, 
	--	Skyreach, Grimrail Depot, Upper Blackrock Spire, The Everbloom
	['D100'] = '964 969 984 987 989 993 995 1008',
	-- Warlords of Draenor dungeons requiring heroic mode to champion
	['H100'] = '',
	-- Warlords of Draenor mixed level dungeons
	['X100'] = '',

	-- Legion PvE territories
	-- Broken Isles, Aszuna, Stormheim, Val'sharah, Broken Shore, Highmountain, Suramar, Argus
	['Legion'] = '1007 1015 1017 1018 1021 1024 1033 1098',
--	['Legion'] = '619, 630, 634 696, 641, 646 676, 650, 680, 905 994',
	-- Legion raids; 
	-- The Emerald Nightmare,  The Nighthold, Trial of Valor, Tomb of Sargeras,
	--	Antorus the Burning Throne
	['Legion Raids'] = '1094 1088 1114 1147 1188',
	-- Legion scenarios
--	['Legion Scenarios'] = '1084 1105 1144 1173 1177 1202 1212 1217',
	-- Legion dungeons
	-- Halls of Valor, Maw of Souls, Vault of the Wardens, Eye of Azshara, Neltharion's Lair, 
	-- Violet Hold, Darkheart Thicket, The Arcway, Black Rook Hold, Court of Stars, 
	-- Return to Karazhan, Cathedral of Eternal Night
	['D110'] = '1041 1042 1045 1046 1065 1066 1067 1079 1081 1087 1115 1146',
	-- Legion dungeons requiring heroic mode to champion
	['H110'] = '',
	-- Legion mixed level dungeons
	['X110'] = '',

	-- BfA territories
	-- Kul Tiras, Zandalar
	['BfA']	= '',
	-- BfA raids
	-- Uldir
	['BfA Raids'] = '',
	-- BfA dungeons
	-- Atal'Dazar, King's Rest, Watcrest Manor, Shrine of the Storm, Siege of Boralus, Underrot, Motherlode, Tol Dagor, Freehold, Yemple of Sethraliss
	['D120'] = '',	
	-- BfA heroic only dungeons
	['H120'] = '',	
	-- BfA mixed mode dungeons
	['X120'] = '',	
	
----------------------------------------------------------------------
--
-- Mapping notes:
--
-- Warlords Garrison mapIDs from GetInstanceInfo()
--	[1152] = FW Horde Garrison Level 1
--	[1330] = FW Horde Garrison Level 2
--	[1153] = FW Horde Garrison Level 3
--	[1154] = FW Horde Garrison Level 4
--	[1158] = SMV Alliance Garrison Level 1
--	[1331] = SMV Alliance Garrison Level 2
--	[1159] = SMV Alliance Garrison Level 3
--	[1160] = SMV Alliance Garrison Level 4
--
--  [1116] = Draenor; all shipyards? 
--
-- These may end up in a tm_maps['garrison'] field later.  Shipyards 
--	do not generate zone change events and do not have their own mapIDs
--	though, so probably will not as the two should be treated the same.
--
-- Legion's Order Halls
--	map		zone							class			instanceID
-- -------------------------------------------------------------------
-- 1052 	Mardum, the Shattered Abyss 	Demon Hunter
-- 1077 	The Dreamgrove 					Druid
-- 1072 	Trueshot Lodge 					Hunter
-- 1068 	Hall of the Guardian 			Mage
-- 1044 	The Wandering Isle 				Monk
-- 1040 	Netherlight Temple 				Priest
-- 1057 	The Heart of Azeroth 			Shaman
-- 1035 	Skyhold 						Warrior			1479
--		 									Death Knight
--											Paladin
--											Rogue			1220
-- 1050		Dreadscar Rift					Warlock
--
----------------------------------------------------------------------
}

-- This is a temporary cross reference table modified from Blizzard's (
-- BlizzardInterfaceCode\Interface\AddOns\Blizzard_Deprecated\UIMapIDToWorldMapAreaID.lua
--
-- Game maps completely changed with client 80000 and now uses the C_Map table as 
-- API interface to all maps.
--
--	C_Map.GetBestMapForUnit('player') returns UiMapID 	(IE: current player map)
--	C_Map.GetMapInfo(uiMapID) returns table {mapType,  mapID,  name,  parentMapID}
--		where:
--			mapType unknown
--			mapID = UiMapID
--			name = localized name of map / zone
--			parentMapID = parent continent / dungeon / etc
--
-- macro: /dump C_Map.GetMapInfo(C_Map.GetBestMapForUnit('player')


-- Stormwind UiMapID 84, mapType 3, parentMapID 13			<- city
-- The Stockade UiMapID 225, mapType 4, parentMapID 84   	<-dungeon
-- L110 Dalaran UiMapID 627, mapType 4, parentMapID 619		<- city


map8ID = {
-- This is for the 8.x map transition. 
-- Previously maps were represented by either by a pair of WorldMapAreaID and DungeonFloor, or a DungeonMapID.
-- In the new system all maps are represented by a UiMapID. 

--			{UiMapID, WorldMapAreaID, DungeonMapID, DungeonFloor}
	[1] =	{1, 4, nil, 0},
	[2] =	{2, 4, 598, 8},
	[3] =	{3, 4, 602, 10},
	[4] =	{4, 4, 603, 11},
	[5] =	{5, 4, 604, 12},
	[6] =	{6, 4, 657, 19},
	[7] =	{7, 9, nil, 0},
	[8] =	{8, 9, 570, 6},
	[9] =	{9, 9, 575, 7},
	[10] =	{10, 11, nil, 0},
	[11] =	{11, 11, 690, 20},
	[12] =	{12, 13, nil, 0},
	[13] =	{13, 14, nil, 0},
	[14] =	{14, 16, nil, 0},
	[15] =	{15, 17, nil, 0},
	[16] =	{16, 17, 695, 18},
	[17] =	{17, 19, nil, 0},
	[18] =	{18, 20, nil, 0},
	[19] =	{19, 20, 592, 13},
	[20] =	{20, 20, 976, 25},
	[21] =	{21, 21, nil, 0},
	[22] =	{22, 22, nil, 0},
	[23] =	{23, 23, nil, 0},
	[24] =	{24, 23, 947, 20},
	[25] =	{25, 24, nil, 0},
	[26] =	{26, 26, nil, 0},
	[27] =	{27, 27, nil, 0},
	[28] =	{28, 27, 581, 6},
	[29] =	{29, 27, 582, 7},
	[30] =	{30, 27, 585, 10},
	[31] =	{31, 27, 587, 11},
	[32] =	{32, 28, nil, 0},
	[33] =	{33, 28, 625, 14},
	[34] =	{34, 28, 626, 15},
	[35] =	{35, 28, 627, 16},
	[36] =	{36, 29, nil, 0},
	[37] =	{37, 30, nil, 0},
	[38] =	{38, 30, 567, 1},
	[39] =	{39, 30, 577, 2},
	[40] =	{40, 30, 706, 19},
	[41] =	{41, 30, 1085, 21},
	[42] =	{42, 32, nil, 0},
	[43] =	{43, 32, 1087, 22},
	[44] =	{44, 32, 1089, 23},
	[45] =	{45, 32, 1090, 24},
	[46] =	{46, 32, 1016, 27},
	[47] =	{47, 34, nil, 0},
	[48] =	{48, 35, nil, 0},
	[49] =	{49, 36, nil, 0},
	[50] =	{50, 37, nil, 0},
	[51] =	{51, 38, nil, 0},
	[52] =	{52, 39, nil, 0},
	[53] =	{53, 39, 579, 4},
	[54] =	{54, 39, 580, 5},
	[55] =	{55, 39, 689, 17},
	[56] =	{56, 40, nil, 0},
	[57] =	{57, 41, nil, 0},
	[58] =	{58, 41, 558, 2},
	[59] =	{59, 41, 564, 3},
	[60] =	{60, 41, 565, 4},
	[61] =	{61, 41, 566, 5},
	[62] =	{62, 42, nil, 0},
	[63] =	{63, 43, nil, 0},
	[64] =	{64, 61, nil, 0},
	[65] =	{65, 81, nil, 0},
	[66] =	{66, 101, nil, 0},
	[67] =	{67, 101, 696, 21},
	[68] =	{68, 101, 699, 22},
	[69] =	{69, 121, nil, 0},
	[70] =	{70, 141, nil, 0},
	[71] =	{71, 161, nil, 0},
	[72] =	{72, 161, 622, 15},
	[73] =	{73, 161, 623, 16},
	[74] =	{74, 161, 631, 17},
	[75] =	{75, 161, 632, 18},
	[76] =	{76, 181, nil, 0},
	[77] =	{77, 182, nil, 0},
	[78] =	{78, 201, nil, 0},
	[79] =	{79, 201, 621, 14},
	[80] =	{80, 241, nil, 0},
	[81] =	{81, 261, nil, 0},
	[82] =	{82, 261, 620, 13},
	[83] =	{83, 281, nil, 0},
	[84] =	{84, 301, nil, 0},
	[85] =	{85, 321, nil, 0},
	[86] =	{86, 321, 118, 1},
	[87] =	{87, 341, nil, 0},
	[88] =	{88, 362, nil, 0},
	[89] =	{89, 381, nil, 0},
	[90] =	{90, 382, nil, 0},
	[91] =	{91, 401, nil, 0},
	[92] =	{92, 443, nil, 0},
	[93] =	{93, 461, nil, 0},
	[94] =	{94, 462, nil, 0},
	[95] =	{95, 463, nil, 0},
	[96] =	{96, 463, 593, 1},
	[97] =	{97, 464, nil, 0},
	[98] =	{98, 464, 594, 2},
	[99] =	{99, 464, 688, 3},
	[100] =	{100, 465, nil, 0},
	[101] =	{101, 466, nil, 0},
	[102] =	{102, 467, nil, 0},
	[103] =	{103, 471, nil, 0},
	[104] =	{104, 473, nil, 0},
	[105] =	{105, 475, nil, 0},
	[106] =	{106, 476, nil, 0},
	[107] =	{107, 477, nil, 0},
	[108] =	{108, 478, nil, 0},
	[109] =	{109, 479, nil, 0},
	[110] =	{110, 480, nil, 0},
	[111] =	{111, 481, nil, 0},
	[112] =	{112, 482, nil, 0},
	[113] =	{113, 485, nil, 0},
	[114] =	{114, 486, nil, 0},
	[115] =	{115, 488, nil, 0},
	[116] =	{116, 490, nil, 0},
	[117] =	{117, 491, nil, 0},
	[118] =	{118, 492, nil, 0},
	[119] =	{119, 493, nil, 0},
	[120] =	{120, 495, nil, 0},
	[121] =	{121, 496, nil, 0},
	[122] =	{122, 499, nil, 0},
	[123] =	{123, 501, nil, 0},
	[124] =	{124, 502, nil, 0},
	[125] =	{125, 504, 27, 1},
	[126] =	{126, 504, 26, 2},
	[127] =	{127, 510, nil, 0},
	[128] =	{128, 512, nil, 0},
	[129] =	{129, 520, 25, 1},
	[130] =	{130, 521, nil, 0},
	[131] =	{131, 521, 34, 1},
	[132] =	{132, 522, 50, 1},
	[133] =	{133, 523, 1, 1},
	[134] =	{134, 523, 2, 2},
	[135] =	{135, 523, 41, 3},
	[136] =	{136, 524, 39, 1},
	[137] =	{137, 524, 40, 2},
	[138] =	{138, 525, 54, 1},
	[139] =	{139, 525, 55, 2},
	[140] =	{140, 526, 53, 1},
	[141] =	{141, 527, 61, 1},
	[142] =	{142, 528, nil, 0},
	[143] =	{143, 528, 42, 1},
	[144] =	{144, 528, 43, 2},
	[145] =	{145, 528, 45, 3},
	[146] =	{146, 528, 46, 4},
	[147] =	{147, 529, nil, 0},
	[148] =	{148, 529, 69, 1},
	[149] =	{149, 529, 70, 2},
	[150] =	{150, 529, 71, 3},
	[151] =	{151, 529, 72, 4},
	[152] =	{152, 529, 98, 5},
	[153] =	{153, 530, nil, 0},
	[154] =	{154, 530, 36, 1},
	[155] =	{155, 531, nil, 0},
	[156] =	{156, 532, 63, 1},
	[157] =	{157, 533, 47, 1},
	[158] =	{158, 533, 48, 2},
	[159] =	{159, 533, 49, 3},
	[160] =	{160, 534, 37, 1},
	[161] =	{161, 534, 38, 2},
	[162] =	{162, 535, 56, 1},
	[163] =	{163, 535, 57, 2},
	[164] =	{164, 535, 58, 3},
	[165] =	{165, 535, 59, 4},
	[166] =	{166, 535, 60, 5},
	[167] =	{167, 535, 73, 6},
	[168] =	{168, 536, 52, 1},
	[169] =	{169, 540, nil, 0},
	[170] =	{170, 541, nil, 0},
	[171] =	{171, 542, 96, 1},
	[172] =	{172, 543, 94, 1},
	[173] =	{173, 543, 95, 2},
	[174] =	{174, 544, nil, 0},
	[175] =	{175, 544, 611, 1},
	[176] =	{176, 544, 614, 2},
	[177] =	{177, 544, 615, 3},
	[178] =	{178, 544, 616, 4},
	[179] =	{179, 545, nil, 0},
	[180] =	{180, 545, 606, 1},
	[181] =	{181, 545, 609, 2},
	[182] =	{182, 545, 610, 3},
	[183] =	{183, 601, 101, 1},
	[184] =	{184, 602, nil, 0},
	[185] =	{185, 603, 102, 1},
	[186] =	{186, 604, 103, 1},
	[187] =	{187, 604, 104, 2},
	[188] =	{188, 604, 105, 3},
	[189] =	{189, 604, 106, 4},
	[190] =	{190, 604, 107, 5},
	[191] =	{191, 604, 108, 6},
	[192] =	{192, 604, 109, 7},
	[193] =	{193, 604, 110, 8},
	[194] =	{194, 605, nil, 0},
	[195] =	{195, 605, 617, 5},
	[196] =	{196, 605, 618, 6},
	[197] =	{197, 605, 619, 7},
	[198] =	{198, 606, nil, 0},
	[199] =	{199, 607, nil, 0},
	[200] =	{200, 609, nil, 0},
	[201] =	{201, 610, nil, 0},
	[202] =	{202, 611, nil, 0},
	[203] =	{203, 613, nil, 0},
	[204] =	{204, 614, nil, 0},
	[205] =	{205, 615, nil, 0},
	[206] =	{206, 626, nil, 0},
	[207] =	{207, 640, nil, 0},
	[208] =	{208, 640, 991, 1},
	[209] =	{209, 640, 992, 2},
	[210] =	{210, 673, nil, 0},
	[213] =	{213, 680, 136, 1},
	[217] =	{217, 684, nil, 0},
	[218] =	{218, 685, nil, 0},
	[219] =	{219, 686, nil, 0},
	[220] =	{220, 687, 176, 1},
	[221] =	{221, 688, 162, 1},
	[222] =	{222, 688, 163, 2},
	[223] =	{223, 688, 164, 3},
	[224] =	{224, 689, nil, 0},
	[225] =	{225, 690, 165, 1},
	[226] =	{226, 691, 168, 1},
	[227] =	{227, 691, 169, 2},
	[228] =	{228, 691, 170, 3},
	[229] =	{229, 691, 172, 4},
	[230] =	{230, 692, 171, 1},
	[231] =	{231, 692, 180, 2},
	[232] =	{232, 696, 181, 1},
	[233] =	{233, 697, nil, 0},
	[234] =	{234, 699, nil, 0},
	[235] =	{235, 699, 262, 1},
	[236] =	{236, 699, 263, 2},
	[237] =	{237, 699, 264, 3},
	[238] =	{238, 699, 265, 4},
	[239] =	{239, 699, 266, 5},
	[240] =	{240, 699, 267, 6},
	[241] =	{241, 700, nil, 0},
	[242] =	{242, 704, 200, 1},
	[243] =	{243, 704, 201, 2},
	[244] =	{244, 708, nil, 0},
	[245] =	{245, 709, nil, 0},
	[246] =	{246, 710, 222, 1},
	[247] =	{247, 717, nil, 0},
	[248] =	{248, 718, 196, 1},
	[249] =	{249, 720, nil, 0},
	[250] =	{250, 721, 202, 1},
	[251] =	{251, 721, 207, 2},
	[252] =	{252, 721, 208, 3},
	[253] =	{253, 721, 209, 4},
	[254] =	{254, 721, 210, 5},
	[255] =	{255, 721, 211, 6},
	[256] =	{256, 722, 214, 1},
	[257] =	{257, 722, 215, 2},
	[258] =	{258, 723, 216, 1},
	[259] =	{259, 723, 217, 2},
	[260] =	{260, 724, 218, 1},
	[261] =	{261, 725, 221, 1},
	[262] =	{262, 726, 223, 1},
	[263] =	{263, 727, 226, 1},
	[264] =	{264, 727, 227, 2},
	[265] =	{265, 728, 228, 1},
	[266] =	{266, 729, 230, 1},
	[267] =	{267, 730, 231, 1},
	[268] =	{268, 730, 232, 2},
	[269] =	{269, 731, 233, 1},
	[270] =	{270, 731, 234, 2},
	[271] =	{271, 731, 235, 3},
	[272] =	{272, 732, 238, 1},
	[273] =	{273, 733, nil, 0},
	[274] =	{274, 734, nil, 0},
	[275] =	{275, 736, nil, 0},
	[276] =	{276, 737, nil, 0},
	[277] =	{277, 747, nil, 0},
	[279] =	{279, 749, 28, 1},
	[280] =	{280, 750, 256, 1},
	[281] =	{281, 750, 257, 2},
	[282] =	{282, 752, 252, 1},
	[283] =	{283, 753, 116, 1},
	[284] =	{284, 753, 117, 2},
	[285] =	{285, 754, 131, 1},
	[286] =	{286, 754, 132, 2},
	[287] =	{287, 755, 182, 1},
	[288] =	{288, 755, 183, 2},
	[289] =	{289, 755, 184, 3},
	[290] =	{290, 755, 185, 4},
	[291] =	{291, 756, 166, 1},
	[292] =	{292, 756, 167, 2},
	[293] =	{293, 757, 123, 1},
	[294] =	{294, 758, 128, 1},
	[295] =	{295, 758, 129, 2},
	[296] =	{296, 758, 134, 3},
	[297] =	{297, 759, 119, 1},
	[298] =	{298, 759, 120, 2},
	[299] =	{299, 759, 135, 3},
	[300] =	{300, 760, 150, 1},
	[301] =	{301, 761, 149, 1},
	[302] =	{302, 762, 137, 1},
	[303] =	{303, 762, 140, 2},
	[304] =	{304, 762, 141, 3},
	[305] =	{305, 762, 179, 4},
	[306] =	{306, 763, 151, 1},
	[307] =	{307, 763, 152, 2},
	[308] =	{308, 763, 153, 3},
	[309] =	{309, 763, 154, 4},
	[310] =	{310, 764, 142, 1},
	[311] =	{311, 764, 143, 2},
	[312] =	{312, 764, 144, 3},
	[313] =	{313, 764, 145, 4},
	[314] =	{314, 764, 146, 5},
	[315] =	{315, 764, 147, 6},
	[316] =	{316, 764, 148, 7},
	[317] =	{317, 765, 155, 1},
	[318] =	{318, 765, 156, 2},
	[319] =	{319, 766, 191, 1},
	[320] =	{320, 766, 192, 2},
	[321] =	{321, 766, 195, 3},
	[322] =	{322, 767, 126, 1},
	[323] =	{323, 767, 127, 2},
	[324] =	{324, 768, 125, 1},
	[325] =	{325, 769, 122, 1},
	[327] =	{327, 772, nil, 0},
	[328] =	{328, 773, 271, 1},
	[329] =	{329, 775, nil, 0},
	[330] =	{330, 776, 322, 1},
	[331] =	{331, 779, 341, 1},
	[332] =	{332, 780, 355, 1},
	[333] =	{333, 781, nil, 0},
	[334] =	{334, 782, 349, 1},
	[335] =	{335, 789, nil, 0},
	[336] =	{336, 789, 440, 1},
	[337] =	{337, 793, nil, 0},
	[338] =	{338, 795, nil, 0},
	[339] =	{339, 796, nil, 0},
	[340] =	{340, 796, 433, 1},
	[341] =	{341, 796, 434, 2},
	[342] =	{342, 796, 435, 3},
	[343] =	{343, 796, 436, 4},
	[344] =	{344, 796, 437, 5},
	[345] =	{345, 796, 438, 6},
	[346] =	{346, 796, 439, 7},
	[347] =	{347, 797, 219, 1},
	[348] =	{348, 798, 236, 1},
	[349] =	{349, 798, 237, 2},
	[350] =	{350, 799, 383, 1},
	[351] =	{351, 799, 385, 2},
	[352] =	{352, 799, 386, 3},
	[353] =	{353, 799, 387, 4},
	[354] =	{354, 799, 388, 5},
	[355] =	{355, 799, 389, 6},
	[356] =	{356, 799, 390, 7},
	[357] =	{357, 799, 391, 8},
	[358] =	{358, 799, 393, 9},
	[359] =	{359, 799, 398, 10},
	[360] =	{360, 799, 399, 11},
	[361] =	{361, 799, 401, 12},
	[362] =	{362, 799, 402, 13},
	[363] =	{363, 799, 403, 14},
	[364] =	{364, 799, 404, 15},
	[365] =	{365, 799, 405, 16},
	[366] =	{366, 799, 406, 17},
	[367] =	{367, 800, nil, 0},
	[368] =	{368, 800, 467, 1},
	[369] =	{369, 800, 466, 2},
	[370] =	{370, 803, 458, 1},
	[371] =	{371, 806, nil, 0},
	[372] =	{372, 806, 678, 6},
	[373] =	{373, 806, 679, 7},
	[374] =	{374, 806, 691, 15},
	[375] =	{375, 806, 692, 16},
	[376] =	{376, 807, nil, 0},
	[377] =	{377, 807, 687, 14},
	[378] =	{378, 808, nil, 0},
	[379] =	{379, 809, nil, 0},
	[380] =	{380, 809, 680, 8},
	[381] =	{381, 809, 682, 9},
	[382] =	{382, 809, 683, 10},
	[383] =	{383, 809, 684, 11},
	[384] =	{384, 809, 685, 12},
	[385] =	{385, 809, 707, 17},
	[386] =	{386, 809, 739, 20},
	[387] =	{387, 809, 740, 21},
	[388] =	{388, 810, nil, 0},
	[389] =	{389, 810, 686, 13},
	[390] =	{390, 811, nil, 0},
	[391] =	{391, 811, 668, 1},
	[392] =	{392, 811, 669, 2},
	[393] =	{393, 811, 670, 3},
	[394] =	{394, 811, 671, 4},
	[395] =	{395, 811, 708, 18},
	[396] =	{396, 811, 709, 19},
	[397] =	{397, 813, nil, 0},
	[398] =	{398, 816, nil, 0},
	[399] =	{399, 819, nil, 0},
	[400] =	{400, 819, 502, 1},
	[401] =	{401, 820, nil, 0},
	[402] =	{402, 820, 495, 1},
	[403] =	{403, 820, 496, 2},
	[404] =	{404, 820, 497, 3},
	[405] =	{405, 820, 498, 4},
	[406] =	{406, 820, 499, 5},
	[407] =	{407, 823, nil, 0},
	[408] =	{408, 823, 1157, 1},
	[409] =	{409, 824, nil, 0},
	[410] =	{410, 824, 503, 1},
	[411] =	{411, 824, 504, 2},
	[412] =	{412, 824, 505, 3},
	[413] =	{413, 824, 512, 4},
	[414] =	{414, 824, 513, 5},
	[415] =	{415, 824, 514, 6},
	[416] =	{416, 851, nil, 0},
	[417] =	{417, 856, nil, 0},
	[418] =	{418, 857, nil, 0},
	[419] =	{419, 857, 727, 1},
	[420] =	{420, 857, 728, 2},
	[421] =	{421, 857, 729, 3},
	[422] =	{422, 858, nil, 0},
	[423] =	{423, 860, 576, 1},
	[424] =	{424, 862, nil, 0},
	[425] =	{425, 864, nil, 0},
	[426] =	{426, 864, 578, 3},
	[427] =	{427, 866, nil, 0},
	[428] =	{428, 866, 584, 9},
	[429] =	{429, 867, 633, 1},
	[430] =	{430, 867, 634, 2},
	[431] =	{431, 871, 639, 1},
	[432] =	{432, 871, 640, 2},
	[433] =	{433, 873, nil, 0},
	[434] =	{434, 873, 677, 5},
	[435] =	{435, 874, 641, 1},
	[436] =	{436, 874, 648, 2},
	[437] =	{437, 875, 649, 1},
	[438] =	{438, 875, 650, 2},
	[439] =	{439, 876, 635, 1},
	[440] =	{440, 876, 636, 2},
	[441] =	{441, 876, 637, 3},
	[442] =	{442, 876, 638, 4},
	[443] =	{443, 877, nil, 0},
	[444] =	{444, 877, 651, 1},
	[445] =	{445, 877, 652, 2},
	[446] =	{446, 877, 653, 3},
	[447] =	{447, 878, nil, 0},
	[448] =	{448, 880, nil, 0},
	[449] =	{449, 881, nil, 0},
	[450] =	{450, 882, nil, 0},
	[451] =	{451, 883, nil, 0},
	[452] =	{452, 884, nil, 0},
	[453] =	{453, 885, 654, 1},
	[454] =	{454, 885, 655, 2},
	[455] =	{455, 885, 656, 3},
	[456] =	{456, 886, nil, 0},
	[457] =	{457, 887, nil, 0},
	[458] =	{458, 887, 660, 1},
	[459] =	{459, 887, 661, 2},
	[460] =	{460, 888, nil, 0},
	[461] =	{461, 889, nil, 0},
	[462] =	{462, 890, nil, 0},
	[463] =	{463, 891, nil, 0},
	[464] =	{464, 891, 599, 9},
	[465] =	{465, 892, nil, 0},
	[466] =	{466, 892, 588, 12},
	[467] =	{467, 893, nil, 0},
	[468] =	{468, 894, nil, 0},
	[469] =	{469, 895, nil, 0},
	[470] =	{470, 895, 583, 8},
	[471] =	{471, 896, 663, 1},
	[472] =	{472, 896, 664, 2},
	[473] =	{473, 896, 665, 3},
	[474] =	{474, 897, 666, 1},
	[475] =	{475, 897, 667, 2},
	[476] =	{476, 898, 642, 1},
	[477] =	{477, 898, 643, 2},
	[478] =	{478, 898, 644, 3},
	[479] =	{479, 898, 645, 4},
	[480] =	{480, 899, 672, 1},
	[481] =	{481, 900, 673, 1},
	[482] =	{482, 900, 674, 2},
	[483] =	{483, 906, nil, 0},
	[486] =	{486, 911, nil, 0},
	[487] =	{487, 912, nil, 0},
	[488] =	{488, 914, nil, 0},
	[489] =	{489, 914, 726, 1},
	[490] =	{490, 919, nil, 0},
	[491] =	{491, 919, 732, 1},
	[492] =	{492, 919, 733, 2},
	[493] =	{493, 919, 734, 3},
	[494] =	{494, 919, 735, 4},
	[495] =	{495, 919, 736, 5},
	[496] =	{496, 919, 737, 6},
	[497] =	{497, 919, 738, 7},
	[498] =	{498, 920, nil, 0},
	[499] =	{499, 922, 741, 1},
	[500] =	{500, 922, 742, 2},
	[501] =	{501, 924, 746, 1},
	[502] =	{502, 924, 748, 2},
	[503] =	{503, 925, 749, 1},
	[504] =	{504, 928, nil, 0},
	[505] =	{505, 928, 758, 1},
	[506] =	{506, 928, 759, 2},
	[507] =	{507, 929, nil, 0},
	[508] =	{508, 930, 750, 1},
	[509] =	{509, 930, 751, 2},
	[510] =	{510, 930, 752, 3},
	[511] =	{511, 930, 753, 4},
	[512] =	{512, 930, 754, 5},
	[513] =	{513, 930, 755, 6},
	[514] =	{514, 930, 756, 7},
	[515] =	{515, 930, 757, 8},
	[516] =	{516, 933, nil, 0},
	[517] =	{517, 933, 761, 1},
	[518] =	{518, 934, 760, 1},
	[519] =	{519, 935, nil, 0},
	[520] =	{520, 937, nil, 0},
	[521] =	{521, 937, 775, 1},
	[522] =	{522, 938, 776, 1},
	[523] =	{523, 939, nil, 0},
	[524] =	{524, 940, nil, 0},
	[525] =	{525, 941, nil, 0},
	[526] =	{526, 941, 815, 1},
	[527] =	{527, 941, 816, 2},
	[528] =	{528, 941, 817, 3},
	[529] =	{529, 941, 818, 4},
	[530] =	{530, 941, 859, 6},
	[531] =	{531, 941, 860, 7},
	[532] =	{532, 941, 861, 8},
	[533] =	{533, 941, 862, 9},
	[534] =	{534, 945, nil, 0},
	[535] =	{535, 946, nil, 0},
	[536] =	{536, 946, 884, 13},
	[537] =	{537, 946, 885, 14},
	[538] =	{538, 946, 937, 30},
	[539] =	{539, 947, nil, 0},
	[540] =	{540, 947, 886, 15},
	[541] =	{541, 947, 894, 22},
	[542] =	{542, 948, nil, 0},
	[543] =	{543, 949, nil, 0},
	[544] =	{544, 949, 888, 16},
	[545] =	{545, 949, 889, 17},
	[546] =	{546, 949, 890, 18},
	[547] =	{547, 949, 891, 19},
	[548] =	{548, 949, 892, 20},
	[549] =	{549, 949, 893, 21},
	[550] =	{550, 950, nil, 0},
	[551] =	{551, 950, 863, 10},
	[552] =	{552, 950, 864, 11},
	[553] =	{553, 950, 880, 12},
	[554] =	{554, 951, nil, 0},
	[555] =	{555, 951, 808, 22},
	[556] =	{556, 953, nil, 0},
	[557] =	{557, 953, 789, 1},
	[558] =	{558, 953, 790, 2},
	[559] =	{559, 953, 793, 3},
	[560] =	{560, 953, 794, 4},
	[561] =	{561, 953, 795, 5},
	[562] =	{562, 953, 796, 6},
	[563] =	{563, 953, 797, 7},
	[564] =	{564, 953, 798, 8},
	[565] =	{565, 953, 800, 9},
	[566] =	{566, 953, 801, 10},
	[567] =	{567, 953, 802, 11},
	[568] =	{568, 953, 803, 12},
	[569] =	{569, 953, 804, 13},
	[570] =	{570, 953, 805, 14},
	[571] =	{571, 955, nil, 0},
	[572] =	{572, 962, nil, 0},
	[573] =	{573, 964, 814, 1},
	[574] =	{574, 969, 828, 1},
	[575] =	{575, 969, 830, 2},
	[576] =	{576, 969, 831, 3},
	[577] =	{577, 970, nil, 0},
	[578] =	{578, 970, 858, 1},
	[579] =	{579, 971, 902, 23},
	[580] =	{580, 971, 903, 24},
	[581] =	{581, 971, 904, 25},
	[582] =	{582, 973, nil, 0},
	[585] =	{585, 976, 905, 26},
	[586] =	{586, 976, 906, 27},
	[587] =	{587, 976, 907, 28},
	[588] =	{588, 978, nil, 0},
	[589] =	{589, 978, 934, 29},
	[590] =	{590, 980, nil, 0},
	[592] =	{592, 983, nil, 0},
	[593] =	{593, 984, 837, 1},
	[594] =	{594, 986, nil, 0},
	[595] =	{595, 987, 839, 1},
	[596] =	{596, 988, 842, 1},
	[597] =	{597, 988, 841, 2},
	[598] =	{598, 988, 840, 3},
	[599] =	{599, 988, 843, 4},
	[600] =	{600, 988, 844, 5},
	[601] =	{601, 989, 845, 1},
	[602] =	{602, 989, 846, 2},
	[606] =	{606, 993, 847, 1},
	[607] =	{607, 993, 848, 2},
	[608] =	{608, 993, 849, 3},
	[609] =	{609, 993, 850, 4},
	[610] =	{610, 994, nil, 0},
	[611] =	{611, 994, 852, 1},
	[612] =	{612, 994, 853, 2},
	[613] =	{613, 994, 854, 3},
	[614] =	{614, 994, 855, 4},
	[615] =	{615, 994, 856, 5},
	[616] =	{616, 995, 877, 1},
	[617] =	{617, 995, 878, 2},
	[618] =	{618, 995, 879, 3},
	[619] =	{619, 1007, nil, 0},
	[620] =	{620, 1008, nil, 0},
	[621] =	{621, 1008, 912, 1},
	[622] =	{622, 1009, nil, 0},
	[623] =	{623, 1010, nil, 0},
	[624] =	{624, 1011, nil, 0},
	[625] =	{625, 1014, nil, 0},
	[626] =	{626, 1014, 993, 4},
	[627] =	{627, 1014, 1009, 10},
	[628] =	{628, 1014, 1010, 11},
	[629] =	{629, 1014, 1011, 12},
	[630] =	{630, 1015, nil, 0},
	[631] =	{631, 1015, 1019, 17},
	[632] =	{632, 1015, 1020, 18},
	[633] =	{633, 1015, 1021, 19},
	[634] =	{634, 1017, nil, 0},
	[635] =	{635, 1017, 1018, 1},
	[636] =	{636, 1017, 1006, 9},
	[637] =	{637, 1017, 1034, 25},
	[638] =	{638, 1017, 1035, 26},
	[639] =	{639, 1017, 1036, 27},
	[640] =	{640, 1017, 1037, 28},
	[641] =	{641, 1018, nil, 0},
	[642] =	{642, 1018, 1012, 13},
	[643] =	{643, 1018, 1013, 14},
	[644] =	{644, 1018, 1014, 15},
	[645] =	{645, 1020, nil, 0},
	[646] =	{646, 1021, nil, 0},
	[647] =	{647, 1021, 939, 1},
	[648] =	{648, 1021, 940, 2},
	[649] =	{649, 1022, nil, 0},
	[650] =	{650, 1024, nil, 0},
	[651] =	{651, 1024, 996, 5},
	[652] =	{652, 1024, 997, 6},
	[653] =	{653, 1024, 1005, 8},
	[654] =	{654, 1024, 1015, 16},
	[655] =	{655, 1024, 1025, 20},
	[656] =	{656, 1024, 1026, 21},
	[657] =	{657, 1024, 1038, 29},
	[658] =	{658, 1024, 1039, 30},
	[659] =	{659, 1024, 1040, 31},
	[660] =	{660, 1024, 1117, 40},
	[661] =	{661, 1026, nil, 0},
	[662] =	{662, 1026, 926, 1},
	[663] =	{663, 1026, 927, 2},
	[664] =	{664, 1026, 925, 3},
	[665] =	{665, 1026, 928, 4},
	[666] =	{666, 1026, 929, 5},
	[667] =	{667, 1026, 930, 6},
	[668] =	{668, 1026, 931, 7},
	[669] =	{669, 1026, 932, 8},
	[670] =	{670, 1026, 933, 9},
	[671] =	{671, 1027, nil, 0},
	[672] =	{672, 1028, nil, 0},
	[673] =	{673, 1028, 1022, 1},
	[674] =	{674, 1028, 1023, 2},
	[675] =	{675, 1028, 1024, 3},
	[676] =	{676, 1031, nil, 0},
	[677] =	{677, 1032, 941, 1},
	[678] =	{678, 1032, 942, 2},
	[679] =	{679, 1032, 943, 3},
	[680] =	{680, 1033, nil, 0},
	[681] =	{681, 1033, 1031, 22},
	[682] =	{682, 1033, 1032, 23},
	[683] =	{683, 1033, 1033, 24},
	[684] =	{684, 1033, 1064, 32},
	[685] =	{685, 1033, 1065, 33},
	[686] =	{686, 1033, 1068, 34},
	[687] =	{687, 1033, 1069, 35},
	[688] =	{688, 1033, 1070, 36},
	[689] =	{689, 1033, 1071, 37},
	[690] =	{690, 1033, 1072, 38},
	[691] =	{691, 1033, 1114, 39},
	[692] =	{692, 1033, 1007, 41},
	[693] =	{693, 1033, 1008, 42},
	[694] =	{694, 1034, nil, 0},
	[695] =	{695, 1035, 946, 1},
	[696] =	{696, 1037, nil, 0},
	[697] =	{697, 1038, nil, 0},
	[698] =	{698, 1039, 948, 1},
	[699] =	{699, 1039, 949, 2},
	[700] =	{700, 1039, 954, 3},
	[701] =	{701, 1039, 958, 4},
	[702] =	{702, 1040, 966, 1},
	[703] =	{703, 1041, nil, 0},
	[704] =	{704, 1041, 963, 1},
	[705] =	{705, 1041, 964, 2},
	[706] =	{706, 1042, nil, 0},
	[707] =	{707, 1042, 967, 1},
	[708] =	{708, 1042, 968, 2},
	[709] =	{709, 1044, nil, 0},
	[710] =	{710, 1045, 969, 1},
	[711] =	{711, 1045, 970, 2},
	[712] =	{712, 1045, 971, 3},
	[713] =	{713, 1046, nil, 0},
	[714] =	{714, 1047, nil, 0},
	[715] =	{715, 1048, nil, 0},
	[716] =	{716, 1049, 973, 1},
	[717] =	{717, 1050, nil, 0},
	[718] =	{718, 1051, nil, 0},
	[719] =	{719, 1052, nil, 0},
	[720] =	{720, 1052, 981, 1},
	[721] =	{721, 1052, 982, 2},
	[723] =	{723, 1054, 974, 1},
	[725] =	{725, 1056, nil, 0},
	[726] =	{726, 1057, nil, 0},
	[728] =	{728, 1059, nil, 0},
	[729] =	{729, 1060, 975, 1},
	[731] =	{731, 1065, nil, 0},
	[732] =	{732, 1066, 977, 1},
	[733] =	{733, 1067, nil, 0},
	[734] =	{734, 1068, 978, 1},
	[735] =	{735, 1068, 979, 2},
	[736] =	{736, 1069, 980, 1},
	[737] =	{737, 1070, 983, 1},
	[738] =	{738, 1071, nil, 0},
	[739] =	{739, 1072, nil, 0},
	[740] =	{740, 1073, 985, 1},
	[741] =	{741, 1073, 986, 2},
	[742] =	{742, 1075, 987, 1},
	[743] =	{743, 1075, 988, 2},
	[744] =	{744, 1076, 989, 1},
	[745] =	{745, 1076, 990, 2},
	[746] =	{746, 1076, 1078, 3},
	[747] =	{747, 1077, nil, 0},
	[748] =	{748, 1078, nil, 0},
	[749] =	{749, 1079, 994, 1},
	[750] =	{750, 1080, nil, 0},
	[751] =	{751, 1081, 998, 1},
	[752] =	{752, 1081, 999, 2},
	[753] =	{753, 1081, 1000, 3},
	[754] =	{754, 1081, 1001, 4},
	[755] =	{755, 1081, 1002, 5},
	[756] =	{756, 1081, 1003, 6},
	[757] =	{757, 1082, nil, 0},
	[758] =	{758, 1084, nil, 0},
	[759] =	{759, 1085, 1027, 1},
	[760] =	{760, 1086, nil, 0},
	[761] =	{761, 1087, nil, 0},
	[762] =	{762, 1087, 1029, 1},
	[763] =	{763, 1087, 1030, 2},
	[764] =	{764, 1088, 1041, 1},
	[765] =	{765, 1088, 1042, 2},
	[766] =	{766, 1088, 1043, 3},
	[767] =	{767, 1088, 1044, 4},
	[768] =	{768, 1088, 1045, 5},
	[769] =	{769, 1088, 1046, 6},
	[770] =	{770, 1088, 1047, 7},
	[771] =	{771, 1088, 1048, 8},
	[772] =	{772, 1088, 1049, 9},
	[773] =	{773, 1090, nil, 0},
	[774] =	{774, 1090, 1050, 1},
	[775] =	{775, 1091, nil, 0},
	[776] =	{776, 1092, nil, 0},
	[777] =	{777, 1094, 1051, 1},
	[778] =	{778, 1094, 1052, 2},
	[779] =	{779, 1094, 1053, 3},
	[780] =	{780, 1094, 1054, 4},
	[781] =	{781, 1094, 1055, 5},
	[782] =	{782, 1094, 1056, 6},
	[783] =	{783, 1094, 1057, 7},
	[784] =	{784, 1094, 1058, 8},
	[785] =	{785, 1094, 1059, 9},
	[786] =	{786, 1094, 1060, 10},
	[787] =	{787, 1094, 1061, 11},
	[788] =	{788, 1094, 1062, 12},
	[789] =	{789, 1094, 1086, 13},
	[790] =	{790, 1096, nil, 0},
	[791] =	{791, 1097, 1066, 1},
	[792] =	{792, 1097, 1067, 2},
	[793] =	{793, 1099, nil, 0},
	[794] =	{794, 1100, 1073, 1},
	[795] =	{795, 1100, 1074, 2},
	[796] =	{796, 1100, 1075, 3},
	[797] =	{797, 1100, 1076, 4},
	[798] =	{798, 1102, 1077, 1},
	[799] =	{799, 1104, nil, 0},
	[800] =	{800, 1104, 1079, 1},
	[801] =	{801, 1104, 1080, 2},
	[802] =	{802, 1104, 1081, 3},
	[803] =	{803, 1104, 1082, 4},
	[804] =	{804, 1105, 1083, 1},
	[805] =	{805, 1105, 1084, 2},
	[806] =	{806, 1114, nil, 0},
	[807] =	{807, 1114, 1091, 1},
	[808] =	{808, 1114, 1092, 2},
	[809] =	{809, 1115, 1093, 1},
	[810] =	{810, 1115, 1094, 2},
	[811] =	{811, 1115, 1095, 3},
	[812] =	{812, 1115, 1096, 4},
	[813] =	{813, 1115, 1097, 5},
	[814] =	{814, 1115, 1098, 6},
	[815] =	{815, 1115, 1099, 7},
	[816] =	{816, 1115, 1100, 8},
	[817] =	{817, 1115, 1101, 9},
	[818] =	{818, 1115, 1102, 10},
	[819] =	{819, 1115, 1103, 11},
	[820] =	{820, 1115, 1104, 12},
	[821] =	{821, 1115, 1105, 13},
	[822] =	{822, 1115, 1106, 14},
	[823] =	{823, 1116, nil, 0},
	[824] =	{824, 1126, nil, 0},
	[825] =	{825, 1127, 1110, 1},
	[826] =	{826, 1129, 1111, 1},
	[827] =	{827, 1130, 1112, 1},
	[828] =	{828, 1131, 1113, 1},
	[829] =	{829, 1132, 1115, 1},
	[830] =	{830, 1135, nil, 0},
	[831] =	{831, 1135, 1163, 1},
	[832] =	{832, 1135, 1165, 2},
	[833] =	{833, 1135, 1184, 7},
	[834] =	{834, 1136, nil, 0},
	[835] =	{835, 1137, 1118, 1},
	[836] =	{836, 1137, 1119, 2},
	[837] =	{837, 1139, nil, 0},
	[838] =	{838, 1140, nil, 0},
	[839] =	{839, 1142, 1123, 1},
	[840] =	{840, 1143, 1120, 1},
	[841] =	{841, 1143, 1121, 2},
	[842] =	{842, 1143, 1122, 3},
	[843] =	{843, 1144, nil, 0},
	[844] =	{844, 1145, nil, 0},
	[845] =	{845, 1146, 1124, 1},
	[846] =	{846, 1146, 1125, 2},
	[847] =	{847, 1146, 1126, 3},
	[848] =	{848, 1146, 1127, 4},
	[849] =	{849, 1146, 1128, 5},
	[850] =	{850, 1147, 1129, 1},
	[851] =	{851, 1147, 1130, 2},
	[852] =	{852, 1147, 1132, 3},
	[853] =	{853, 1147, 1133, 4},
	[854] =	{854, 1147, 1134, 5},
	[855] =	{855, 1147, 1135, 6},
	[856] =	{856, 1147, 1136, 7},
	[857] =	{857, 1148, 1138, 1},
	[858] =	{858, 1149, nil, 0},
	[859] =	{859, 1150, nil, 0},
	[860] =	{860, 1151, nil, 0},
	[861] =	{861, 1152, nil, 0},
	[862] =	{862, 1153, nil, 0},
	[863] =	{863, 1154, nil, 0},
	[864] =	{864, 1155, nil, 0},
	[865] =	{865, 1156, 1143, 1},
	[866] =	{866, 1156, 1144, 2},
	[867] =	{867, 1157, 1140, 1},
	[868] =	{868, 1158, 1139, 1},
	[869] =	{869, 1159, 1141, 1},
	[870] =	{870, 1159, 1142, 2},
	[871] =	{871, 1160, nil, 0},
	[872] =	{872, 1161, nil, 0},
	[873] =	{873, 1161, 1145, 1},
	[874] =	{874, 1161, 1146, 2},
	[875] =	{875, 1162, nil, 0},
	[876] =	{876, 1163, nil, 0},
	[877] =	{877, 1164, nil, 0},
	[878] =	{878, 1165, nil, 0},
	[879] =	{879, 1165, 1147, 1},
	[880] =	{880, 1165, 1148, 2},
	[881] =	{881, 1166, 1150, 1},
	[882] =	{882, 1170, nil, 0},
	[883] =	{883, 1170, 1166, 3},
	[884] =	{884, 1170, 1167, 4},
	[885] =	{885, 1171, nil, 0},
	[886] =	{886, 1171, 1168, 5},
	[887] =	{887, 1171, 1169, 6},
	[888] =	{888, 1172, 1154, 1},
	[889] =	{889, 1173, 1149, 1},
	[890] =	{890, 1173, 1156, 2},
	[891] =	{891, 1174, nil, 0},
	[892] =	{892, 1174, 1181, 1},
	[893] =	{893, 1174, 1179, 2},
	[894] =	{894, 1174, 1180, 3},
	[895] =	{895, 1175, nil, 0},
	[896] =	{896, 1176, nil, 0},
	[897] =	{897, 1177, nil, 0},
	[898] =	{898, 1177, 1158, 1},
	[899] =	{899, 1177, 1159, 2},
	[900] =	{900, 1177, 1160, 3},
	[901] =	{901, 1177, 1161, 4},
	[902] =	{902, 1177, 1162, 5},
	[903] =	{903, 1178, nil, 0},
	[904] =	{904, 1183, nil, 0},
	[905] =	{905, 1184, nil, 0},
	[906] =	{906, 1185, nil, 0},
	[907] =	{907, 1186, nil, 0},
	[908] =	{908, 1187, nil, 0},
	[909] =	{909, 1188, nil, 0},
	[910] =	{910, 1188, 1170, 1},
	[911] =	{911, 1188, 1171, 2},
	[912] =	{912, 1188, 1172, 3},
	[913] =	{913, 1188, 1173, 4},
	[914] =	{914, 1188, 1174, 5},
	[915] =	{915, 1188, 1175, 6},
	[916] =	{916, 1188, 1176, 7},
	[917] =	{917, 1188, 1177, 8},
	[918] =	{918, 1188, 1178, 9},
	[919] =	{919, 1188, 1182, 10},
	[920] =	{920, 1188, 1183, 11},
	[921] =	{921, 1190, nil, 0},
	[922] =	{922, 1191, nil, 0},
	[923] =	{923, 1192, nil, 0},
	[924] =	{924, 1193, nil, 0},
	[925] =	{925, 1194, nil, 0},
	[926] =	{926, 1195, nil, 0},
	[927] =	{927, 1196, nil, 0},
	[928] =	{928, 1197, nil, 0},
	[929] =	{929, 1198, nil, 0},
	[930] =	{930, 1199, nil, 0},
	[931] =	{931, 1200, nil, 0},
	[932] =	{932, 1201, nil, 0},
	[933] =	{933, 1202, nil, 0},
	[934] =	{934, 1204, 1185, 1},
	[935] =	{935, 1204, 1186, 2},
	[936] =	{936, 1205, nil, 0},
	[938] =	{938, 1210, nil, 0},
	[939] =	{939, 1211, nil, 0},
	[940] =	{940, 1212, 1188, 1},
	[941] =	{941, 1212, 1189, 2},
	[942] =	{942, 1213, nil, 0},
	[943] =	{943, 1214, nil, 0},
	[971] =	{971, 1215, nil, 0},
	[972] =	{972, 1216, nil, 0},
	[973] =	{973, 1217, 1190, 1},
	[974] =	{974, 1219, nil, 0},
	[975] =	{975, 1219, 1191, 1},
	[976] =	{976, 1219, 1192, 2},
	[977] =	{977, 1219, 1193, 3},
	[978] =	{978, 1219, 1194, 4},
	[979] =	{979, 1219, 1195, 5},
	[980] =	{980, 1219, 1196, 6},
	[981] =	{981, 1220, nil, 0},
	[994] =	{994, 1184, nil, 0},
	[998] =	{998, 382, nil, 0},
}
